(function(own) {

	//String

	/**
	 * 删除左右两端的空格
	 */
	String.prototype.trim = function() {
		return this.replace(/(^\s*)|(\s*$)/g, '');
	}
	/**
	 * 删除左边的空格
	 */
	String.prototype.ltrim = function() {
		return this.replace(/(^\s*)/g, '');
	}
	/**
	 * 删除右边的空格
	 */
	String.prototype.rtrim = function() {
		return this.replace(/(\s*$)/g, '');
	}

	/**
	 * 金额大写
	 */
	String.prototype.toCapitalMoney = function() {
		var number = this;
		var prefix = '';
		if (number.substr(0, 1) == '-') {
			prefix = '负';
			number = number.substr(1);
		}
		if (!/^(0|[1-9]\d*)(\.\d{1,2})?$/.test(number)) {
			return '金额格式错误';
		}
		var unit = "仟佰拾亿仟佰拾万仟佰拾元角分",
			str = "";
		number += "00";
		var point = number.indexOf('.');
		if (point >= 0) {
			number = number.substring(0, point) + number.substr(point + 1, 2);
		}
		unit = unit.substr(unit.length - number.length);
		for (var i = 0; i < number.length; i++) {
			str += '零壹贰叁肆伍陆柒捌玖'.charAt(number.charAt(i)) + unit.charAt(i);
		}
		return prefix + str.replace(/零(仟|佰|拾|角)/g, "零").replace(/(零)+/g, "零").replace(/零(万|亿|元)/g, "$1").replace(
			/(亿)万|(拾)/g, "$1$2").replace(/^元零?|零分/g, "").replace(/元$/g, "元整");
	};

	//字符串起止
	String.prototype.startWith = function(str) {
		var reg = new RegExp("^" + str);
		return reg.test(this);
	};
	String.prototype.endWith = function(str) {
		var reg = new RegExp(str + "$");
		return reg.test(this);
	};

	/**
	 * 字符串转为时间
	 * 2017-04-17 01:12:23
	 * 2017-04-17
	 */
	String.prototype.toDate = function() {
		return new Date(Date.parse(this.replace(/-/g, "/")));
	}

	String.prototype.mjFormat = function() {
		var args = [].slice.call(arguments);
		return this.replace(/(\{\d+\})/g, function(a) {
			return args[+(a.substr(1, a.length - 2)) || 0];
		});
	};

	String.prototype.queryToJson = function() {
		var obj = {};
		var keyValue = [];
		var key = "",
			value = "";
		var paraString = this.split("&");
		for (var i in paraString) {
			keyValue = paraString[i].split("=");
			key = keyValue[0];
			value = keyValue[1];
			obj[key] = value;
		}
		return obj;
	};

	//Date
	Date.prototype.format = function(formatPtn) {
		var o = {
			"M+": this.getMonth() + 1, //month
			"d+": this.getDate(), //day
			"h+": this.getHours(), //hour
			"m+": this.getMinutes(), //minute
			"s+": this.getSeconds(), //second
			"q+": Math.floor((this.getMonth() + 3) / 3), //quarter
			"S": this.getMilliseconds() //millisecond
		}
		if (/(y+)/.test(formatPtn)) formatPtn = formatPtn.replace(RegExp.$1, (this.getFullYear() + "").substr(4 - RegExp.$1
			.length));
		for (var k in o) {
			if (new RegExp("(" + k + ")").test(formatPtn)) {
				formatPtn = formatPtn.replace(RegExp.$1, RegExp.$1.length == 1 ? o[k] : ("00" + o[k]).substr(("" + o[k]).length));
			}
		}
		return formatPtn;
	}

	Date.prototype.fixTimezone = function(offset) {
		offset = offset || 8;
		var utc = this.getTime() + (this.getTimezoneOffset() * 60000);
		return new Date(utc + (3600000 * offset));
	}

	Date.prototype.previous = function(n) {
		//		return new Date(this.getFullYear(),this.getMonth(),this.getDate()-n);
		return new Date(this.getTime() - Number(n) * 24 * 60 * 60 * 1000);
	}

	Date.prototype.next = function(n) {
		//		return new Date(this.getFullYear(),this.getMonth(),this.getDate()+n);
		return new Date(this.getTime() + Number(n) * 24 * 60 * 60 * 1000);
	}

	var now = new Date(); //当前日期
	var nowDayOfWeek = now.getDay(); //今天本周的第几天
	var nowDay = now.getDate(); //当前日
	var nowMonth = now.getMonth(); //当前月
	var nowYear = now.getFullYear(); //当前年

	//格局化日期：yyyy-MM-dd
	own.formatDate = function(date) {
		var myYear = date.getFullYear();
		var myMonth = date.getMonth() + 1;
		var myWeekday = date.getDate();

		if (myMonth < 10) {
			myMonth = "0" + myMonth;
		}
		if (myWeekday < 10) {
			myWeekday = "0" + myWeekday;
		}
		return (myYear + "-" + myMonth + "-" + myWeekday);
	}

	//格局化月份:yy-MM
	own.formatMonth = function(date) {
		var myYear = date.getFullYear();
		var myMonth = date.getMonth() + 1;

		if (myMonth < 10) {
			myMonth = "0" + myMonth;
		}

		return (myYear + "-" + myMonth);
	}

	//获得某月的天数
	own.fnGetMonthDays = function(year, month) {
		var time = new Date(year, month, 0);
		return time.getDate();
	}

	own.getMonthDays = function(myMonth) {
		var monthStartDate = new Date(nowYear, myMonth, 1);
		var monthEndDate = new Date(nowYear, myMonth + 1, 1);
		return (monthEndDate - monthStartDate) / (1000 * 60 * 60 * 24);
	}

	//获取当天日期
	own.getToday = function() {
		return formatDate(new Date());
	}

	//获得本周的开端日期
	own.getWeekStartDate = function() {
		var weekStartDate = new Date(nowYear, nowMonth, nowDay - nowDayOfWeek);
		return formatDate(weekStartDate);
	}
	//获得本周的停止日期
	own.getWeekEndDate = function() {
		var weekEndDate = new Date(nowYear, nowMonth, nowDay + (5 - nowDayOfWeek));
		return formatDate(weekEndDate);
	}
	//获得本月的开端日期
	own.getMonthStartDate = function() {
		var monthStartDate = new Date(nowYear, nowMonth, 1);
		return formatDate(monthStartDate);
	}
	//获得本月的停止日期
	own.getMonthEndDate = function() {
		var monthEndDate = new Date(nowYear, nowMonth, getMonthDays(nowMonth));
		return formatDate(monthEndDate);
	}

	own.fnGetMonthEndDate = function(timeStr) {
		var time = timeStr.toDate();
		var year = time.getFullYear();
		var month = time.getMonth();
		var monthEndDate = new Date(year, month, fnGetMonthDays(year, month + 1));
		return formatDate(monthEndDate);
	}
	//获得本季度的开端日期
	own.getQuarterStartDate = function() {
		var quarterStartDate = new Date(nowYear, getQuarterStartMonth(), 1);
		return formatDate(quarterStartDate);
	}
	//获得本季度的停止日期
	own.getQuarterEndDate = function() {
		var quarterEndMonth = getQuarterStartMonth() + 2;
		var quarterStartDate = new Date(nowYear, quarterEndMonth, getMonthDays(quarterEndMonth));
		return formatDate(quarterStartDate);
	}
	//获得本年的停止日期
	own.getYearEndDate = function() {
		var quarterEndMonth = 11;
		var quarterStartDate = new Date(nowYear, quarterEndMonth, getMonthDays(quarterEndMonth));
		return formatDate(quarterStartDate);
	}
	//获得本季度的开端月份
	own.getQuarterStartMonth = function() {
		var quarterStartMonth = 0;
		if (nowMonth < 3) {
			quarterStartMonth = 0;
		}
		if (2 < nowMonth && nowMonth < 6) {
			quarterStartMonth = 3;
		}
		if (5 < nowMonth && nowMonth < 9) {
			quarterStartMonth = 6;
		}
		if (nowMonth > 8) {
			quarterStartMonth = 9;
		}
		return quarterStartMonth;
	}
	//本年的第一个月
	own.getYearStartMonth = function() {
		var yearStartMonth = new Date(nowYear, 0);
		return formatMonth(yearStartMonth);
	}
	//获得本年的当前月份
	own.getYearCurrentMonth = function() {
		var yearEndMonth = new Date(nowYear, nowMonth);
		return formatMonth(yearEndMonth);
	}

	own.parseDate = function(dateStr) {
		return new Date(Date.parse(dateStr.replace(/-/g, "/")));
	}

	own.validateDateRange = function(startTime, endTime) {
		var searchStart = parseDate(startTime);
		var searchEnd = parseDate(endTime);
		return searchStart <= searchEnd;
	}

	own.validateTimeRange = function(startTime, endTime) {
		var searchStart = parseDate(startTime);
		var searchEnd = parseDate(endTime);
		return searchStart < searchEnd;
	}

	own.loadJs = function(jsUrl, callback) {
		var script = document.createElement("script");
		script.type = "text/javascript";
		script.src = jsUrl;
		script.addEventListener('load', function() {
			callback && callback();
		});
		document.head.appendChild(script);
	};

	own.log = function(msg, obj) {
		var str = (new Date()).format('yyyy-MM-dd hh:mm:ss') + ', ' + msg;
		if (obj) str += JSON.stringify(obj);
		console.log(str);
	}

	own.getLaunchView = function(callback) {
		if (!own.plus) {
			setTimeout(function() {
				own.getLaunchView(callback);
			}, 100);
			return;
		}
		callback && callback(plus.webview.getLaunchWebview());
	}

	own.showAllViews = function() {
		var wvs = plus.webview.all();
		for (var i = 0; i < wvs.length; i++) {
			log(wvs[i].id);
		}
	}

	//当页面hide的时候将其中的页面close掉
	own.closeChildWebviewOfhide = function(currentWebview, closedWebviewId) {
		currentWebview.addEventListener('hide', function() {

			var closeWeb = plus.webview.getWebviewById(closedWebviewId);

			if (!currentWebview.getURL() || !closeWeb) {
				return;
			}
			closeWeb.close();
			closeWeb = null;
		}, false);
	}

	//当页面close的时候将其中的页面close掉
	own.closeChildWebviewOfclose = function(currentWebview, closedWebviewId) {
		currentWebview.addEventListener('close', function() {
			var closeWeb = plus.webview.getWebviewById(closedWebviewId);
			if (!currentWebview.getURL() || !closeWeb) {
				return;
			}
			closeWeb.close();
			closeWeb = null;
		}, false);
	}

	//一般情况下设置anishow
	own.getaniShow = function() {
		var aniShow = 'slide-in-right';
		if (mui.os.android) {
			var androidlist = document.querySelectorAll('ios-only');
			if (androidlist) {
				mui.each(androidlist, function(num, obj) {
					obj.style.display = 'none';
				});
			}

			if (parseFloat(mui.os.version) < 4.4) {
				aniShow = 'slide-in-right';
			}
		}

		return aniShow;
	}

	own.pushWebView = function(options) {
		var webview = plus.webview.getWebviewById(view_temp);
		mui.fire(webview, options.webType, {
			id: options.id,
			href: options.href,
			aniShow: options.aniShow,
			title: options.title,
			isBars: options.isBars,
			barsIcon: options.barsIcon,
			extendOptions: options.extendOptions
		});
	}

	own.pushUserSelectWebView = function(options) {
		options = options || {};

		function onUserSelectedHandler(result) {
			window.removeEventListener(event_user_selected, onUserSelectedHandler, false);
			options.callback && options.callback(result.detail);
		}

		window.addEventListener(event_user_selected, onUserSelectedHandler, false);

		window.addEventListener(event_user_cancel_selected, function() {
			window.removeEventListener(event_user_selected, onUserSelectedHandler, false);
		}, false);

		var parentWebviewId = plus.webview.currentWebview().id;
		var templateView = plus.webview.getWebviewById(view_temp);
		options.parentWebviewId = parentWebviewId;
		mui.fire(templateView, event_show_select_page_for_user, {
			aniShow: getaniShow(),
			extendOptions: options
		});
	}

	own.pushUserScanWebView = function(options) {
		options = options || {};

		var parentWebviewId = plus.webview.currentWebview().id;
		var templateView = plus.webview.getWebviewById(view_temp);
		options.parentWebviewId = parentWebviewId;
		mui.fire(templateView, event_show_scan_page_for_user, {
			aniShow: getaniShow(),
			extendOptions: options
		});
	}

	own.pushInVoiceScanWebView = function(options) {
		options = options || {};

		function onInvoiceScannedHandler(result) {
			window.removeEventListener(event_invoice_scanned, onInvoiceScannedHandler, false);
			options.callback && options.callback(result.detail);
		}

		function onCancelInvoiceScannedHandler() {
			window.removeEventListener(event_invoice_scanned, onInvoiceScannedHandler, false);
			window.removeEventListener(event_invoice_cancel_scanned, onCancelInvoiceScannedHandler, false);
			options.cancelCallback && options.cancelCallback();
		}

		window.addEventListener(event_invoice_scanned, onInvoiceScannedHandler, false);

		window.addEventListener(event_invoice_cancel_scanned, onCancelInvoiceScannedHandler, false);

		var parentWebviewId = plus.webview.currentWebview().id;
		var templateView = plus.webview.getWebviewById(view_temp);
		options.parentWebviewId = parentWebviewId;
		mui.fire(templateView, event_show_scan_page_for_invoice, {
			aniShow: getaniShow(),
			extendOptions: options
		});
	}

	own.showBillBaseData = function(feeType, feeDm, feeDid, paramDm) {
		var id = 'bill_report_base_data_temp.html';
		var href = 'file://' + plus.io.convertLocalFileSystemURL(id);
		var title = '';
		var isBars = false;
		var barsIcon = '';
		var aniShow = getaniShow();

		var temp = 'newWebview_Second';

		switch (feeType) {
			case 'profit':
			case 'profit-income':
			case 'profit-cost':
			case 'profit-fee':
			case 'profit-other':
				title = '利润分析明细表';
				feeDm = 0;
				feeDid = 0;
				break;
			case 'income':
				title = '收入分析明细表';
				break;
			case 'cost':
				title = '成本分析明细表';
				break;
			case 'fee':
			default:
				title = '费用分析明细表';
				break;
		}

		paramDm += '&s=' + feeDm + '.' + feeDid;

		pushWebView({
			webType: temp,
			id: id,
			href: href,
			aniShow: aniShow,
			title: title,
			isBars: isBars,
			barsIcon: barsIcon,
			extendOptions: {
				noCache: true,
				dm: paramDm
			}
		})
	}

	own.showDailylogBaseData = function(dm, hasConsumer) {
		var id = 'dailylog_report_base_data_temp.html';
		var href = 'file://' + plus.io.convertLocalFileSystemURL(id);
		var title = '';
		var isBars = false;
		var barsIcon = '';
		var aniShow = getaniShow();

		var temp = 'newWebview_Second';

		if (hasConsumer == 'y') {
			title = '客户拜访明细表';
		} else {
			title = '工作日报分析明细表';
		}

		pushWebView({
			webType: temp,
			id: id,
			href: href,
			aniShow: aniShow,
			title: title,
			isBars: isBars,
			barsIcon: barsIcon,
			extendOptions: {
				noCache: true,
				dm: dm,
				hasConsumer: hasConsumer
			}
		})
	}

	own.showSaleConsumerVisitBaseData = function(dm, hasConsumer) {
		var id = 'sale_consumer_visit_detail_report_temp.html';
		var href = 'file://' + plus.io.convertLocalFileSystemURL(id);
		var title = '客户拜访明细表';
		var isBars = false;
		var barsIcon = '';
		var aniShow = getaniShow();

		var temp = 'newWebview_Second';

		pushWebView({
			webType: temp,
			id: id,
			href: href,
			aniShow: aniShow,
			title: title,
			isBars: isBars,
			barsIcon: barsIcon,
			extendOptions: {
				noCache: true,
				dm: dm
			}
		})
	}

	own.showNewConsumerData = function(dm, dmSrcName, didName) {
		var id = 'sale_new_consumer_data_temp.html';
		var href = 'file://' + plus.io.convertLocalFileSystemURL(id);
		var title = '新增客户数据分析表';
		var isBars = false;
		var barsIcon = '';
		var aniShow = getaniShow();

		var temp = 'newWebview_Second';

		pushWebView({
			webType: temp,
			id: id,
			href: href,
			aniShow: aniShow,
			title: title,
			isBars: isBars,
			barsIcon: barsIcon,
			extendOptions: {
				noCache: true,
				dm: dm,
				dmSrcName: dmSrcName,
				didName: didName
			}
		})
	}

	own.showBillDetailView = function(temp, billId, billType) {
		var billName = mj.getBillName(billType);
		var href;
		var isBars = false;
		var barsIcon = '';
		switch (Number(billType)) {
			case BILL_TYPE_REPAYMENT:
				href = 'views/bill/repayment_bill_detail_temp.html';
				break;
			case BILL_TYPE_TRAVEL:
				href = 'views/bill/travel_bill_detail_temp.html';
				break;
			case BILL_TYPE_SUPPLIER_PREPAY:
				href = 'views/bill/supplier_prepay_bill_detail_temp.html';
				break;
			case BILL_TYPE_SUPPLIER_PAY:
				href = 'views/bill/supplier_pay_bill_detail_temp.html';
				break;
			case BILL_TYPE_BANK_DEDUCTION:
				href = 'views/bill/deduction_bill_detail_temp.html';
				break;
			case BILL_TYPE_DEPRECIATION:
				href = 'views/bill/depreciation_bill_detail_temp.html';
				break;
			case BILL_TYPE_ACCRUED:
				href = 'views/bill/accrued_bill_detail_temp.html';
				break;
			case BILL_TYPE_SUPPLIER_ASSET:
				href = 'views/bill/supplier_asset_bill_detail_temp.html';
				break;
			case BILL_TYPE_SUPPLIER_PAY_GOODS:
				href = 'views/bill/supplier_pay_goods_bill_detail_temp.html';
				break;
			case BILL_TYPE_SUPER:
				href = 'views/bill/super_bill_detail_temp.html';
				break;
			case BILL_TYPE_MATERIAL_REQ:
				href = 'views/bill/material_req_bill_detail_temp.html';
				break;
			case BILL_TYPE_SALE:
				href = 'views/bill/sale_bill_detail_temp.html';
				break;
			case BILL_TYPE_COLLECTION:
				href = 'views/bill/collection_bill_detail_temp.html';
				break;
			case BILL_TYPE_BUDGET_COLLECT:
				href = 'views/bill/budget_collect_bill_detail_temp.html';
				break;
			case BILL_TYPE_BUDGET_PAY:
				href = 'views/bill/budget_pay_bill_detail_temp.html';
				break;
			case BILL_TYPE_TRANSFER:
				href = 'views/bill/transfer_bill_detail_temp.html';
				break;
			default:
				href = '';
				log('no bill type specified');
				return;
		}

		pushWebView({
			webType: temp,
			id: href,
			href: href,
			aniShow: 'slide-in-right',
			title: billName,
			isBars: isBars,
			barsIcon: barsIcon,
			extendOptions: {
				billId: billId,
				noCache: true
			}
		})
	}

	//设置是否需要bounce，一般有scroll的地方会将bounce取消掉
	own.setSubWebviewBounce = function(bounce) {
		var curSubWebview = plus.webview.currentWebview();
		curSubWebview.setStyle({
			bounce: bounce
		});
	}

	own.setMask = function(options) {
		var menu = null;
		var mask = null;
		var maskBool = true;
		var main = plus.webview.getWebviewById('HBuilder');
		mui.fire(main, 'showMask', {
			'id': plus.webview.currentWebview().id
		});

		if (mask == null) {
			mask = mui.createMask(function() {
				if (maskBool == true) {
					//menu.close();
					mui.fire(main, 'hiddeMask', {});
				}
			});
		} else {
			maskBool = true;
		}
		mask.show();

		document.addEventListener('hiddeMask', function() {
			maskBool = false;
			mask.close();
			//menu.close();
		});

		menu = mui.preload({
			id: 'offcanvas-drag-left-plus-menu',
			url: '../event/webview_Alert.html',
			styles: {
				left: "30%",
				height: '200px',
				width: '200px',
				zindex: 99999
			}
		});

		var main = plus.webview.currentWebview();
		menu.show();
	}

	//部门员工
	own.mjQueryUsersByDepartment = function(departmentId, callback, errCallback) {
		mj.get(MJ_URL.USER_LIST_BY_DEPT.mjFormat(departmentId), {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//全部员工
	own.mjQueryUsersAll = function(callback, errCallback) {
		mj.get(MJ_URL.USER_LIST_BY_ALL, {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//直接下级员工
	own.mjQuerySubMentors = function(callback) {
		mj.get(MJ_URL.USER_LIST_BY_MENTOR, {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//项目成员
	own.mjQueryUsersByProject = function(projectId, callback, errCallback) {
		mj.get(MJ_URL.USER_LIST_BY_PROJ.mjFormat(projectId), {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//权限员工
	own.mjQueryUsersByPermission = function(opt, callback, errCallback) {
		var params = {};
		params.mm = opt.mm;
		params.t1 = opt.t1;
		mj.get(MJ_URL.USER_LIST_BY_PERMISSION, params, function(res) {
			if (res && res.status == SYSTEM_SUCCEED) {
				callback && callback(res.data);
			} else {
				showFromCode(res.status);
			}
		}, errCallback);
	}

	//访问权限
	own.mjQueryPermission = function(opt,callback){
		var params = {};
		params.mm = opt.mm;
		params.t1 = opt.t1;
		if(opt.t2) params.t2 = opt.t2;
		mj.get(MJ_URL.PERMISSION_CHECK, params, function(res) {
			if(res && res.status == SYSTEM_SUCCEED){
				callback && callback(res.data);
			}else{
				showFromCode(res.status);
			}
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	own.mj = {
		serverUrlDef: 'serverUrl',
		serverNameDef: 'serverName',
		serverVersionDef: 'serverVersion',
		appVersionDef: 'appVersion',
		tokenDef: 'token',
		idDef: 'id',
		nameDef: 'name',
		accountIdDef: 'accountId',
		accountNameDef: 'accountName',
		accountListDef: 'accountList',
		isGmDef: 'isGm',
		isFmDef: 'isFm',
		isHmDef: 'isHm',
		isSmDef: 'isSm',
		permissionDef: 'permission',
		isFeeDmDef: 'isFeeDm',
		isFeePmDef: 'isFeePm',
		isHrDmDef: 'isHrDm',
		isForceLogoutDef: 'isForceLogout',
		compressDef: 'compress',
		multipleDef: 'multiple',
		msgAlertDef: 'msgAlert',
		nickNameDef: 'nickName',
		positionNameDef: 'positionName',
		mentorDef: 'mentor',
		subsDef: 'subs',
		manageDepartmentDef: 'manageDepartment',
		manageProjectDef: 'manageProject',
		departmentIdDef: 'departmentId',
		departmentNameDef: 'departmentName',
		departmentsDef: 'departments',
		projectsDef: 'projects',
		wcsDef: 'wcs',
		bizesDef: 'bizes',
		dictsDef: 'dicts',
		warnRulesDef: 'warnRules',
		dictsPref: 'dict-',
		billsPref: 'bills-',
		modulePref: 'module-',
		globalIsBackCustomizeDef: 'isBackCustomize',
		init: function() {
			log('mj init start...');

			this.queryVersion();

			log('mj init end.');
		},
		isNewVersion: function(baseV, curV) {
			//isNewVersion('2.12.10','2.12.20'),返回值17
			//isNewVersion('2.12.10','2.12.10'),返回值0
			//isNewVersion('2.12.10','2.12.5'),返回值-5
			var arr1 = curV.split('.');
			var arr2 = baseV.split('.');
			var minL = Math.min(arr1.length, arr2.length);
			var pos = 0,
				diff = 0;
			while (pos < minL) {
				diff = parseInt(arr1[pos]) - parseInt(arr2[pos]);
				if (diff != 0) {
					break;
				}
				pos++;
			}
			return diff;
		},
		queryVersion: function() {
			var self = this;
			// mui.getJSON("manifest.json", null, function(data) {
			// 	var version = data.version;
			// 	version = version.name + '.' + version.code;
			// 	self.setVersion(version);
			// 	log('version query:' + version);
			// });
			var versionDir = 'manifest.json';
			var localPath = plus.io.convertLocalFileSystemURL(versionDir);
			if (plus.os.name == 'iOS') {
				localPath = 'file://' + localPath;
			}
			plus.io.resolveLocalFileSystemURL(localPath, function(entry) {
				entry.file(function(file) {
					var fileReader = new plus.io.FileReader();
					fileReader.readAsText(file, 'utf-8');
					fileReader.onloadend = function(evt) {
						var data = JSON.parse(evt.target.result);
						var version = data.version;
						version = version.name + '.' + version.code;
						self.setVersion(version);
						log('version:' + version);
					}
				});
			}, function(e) {
				log("Resolve manifest.json URL failed: " + e.message);
			});
		},
		setVersion: function(version) {
			localStorage.setItem(this.appVersionDef, version);
		},
		getVersion: function() {
			return localStorage.getItem(this.appVersionDef);
		},
		getServerUrl: function() {
			return localStorage.getItem(this.serverUrlDef);
		},
		getServerName: function() {
			return localStorage.getItem(this.serverNameDef);
		},
		getServerVersion: function() {
			var sv = localStorage.getItem(this.serverVersionDef);
			return sv == null ? '1.0.1' : sv;
		},
		getToken: function() {
			return localStorage.getItem(this.tokenDef);
		},
		getId: function() {
			return localStorage.getItem(this.idDef);
		},
		getName: function() {
			return localStorage.getItem(this.nameDef);
		},
		getAccountId: function() {
			return localStorage.getItem(this.accountIdDef);
		},
		getAccountName: function() {
			return localStorage.getItem(this.accountNameDef);
		},
		getAccountList: function() {
			return localStorage.getItem(this.accountListDef);
		},
		getIsGM: function() {
			return localStorage.getItem(this.isGmDef);
		},
		getIsFM: function() {
			return localStorage.getItem(this.isFmDef);
		},
		getIsHM: function() {
			return localStorage.getItem(this.isHmDef);
		},
		getIsSM: function() {
			return localStorage.getItem(this.isSmDef);
		},
		getIsFeeDM: function() {
			return localStorage.getItem(this.isFeeDmDef);
		},
		getIsFeePM: function() {
			return localStorage.getItem(this.isFeePmDef);
		},
		getIsHrDM: function() {
			return localStorage.getItem(this.isHrDmDef);
		},
		isForceLogout: function() {
			var value = localStorage.getItem(this.isForceLogoutDef);
			return value != null && value == 'true';
		},
		setForceLogout: function() {
			localStorage.setItem(this.isForceLogoutDef, 'true');
		},
		resetForceLogout: function() {
			localStorage.setItem(this.isForceLogoutDef, 'false');
		},
		getCompress: function() {
			var needCompress = localStorage.getItem(this.compressDef);
			return needCompress == null || needCompress == 'true';
		},
		setCompress: function(needCompress) {
			localStorage.setItem(this.compressDef, needCompress);
		},
		getMultiple: function() {
			var canMultiple = localStorage.getItem(this.multipleDef);
			return canMultiple == null || canMultiple == 'true';
		},
		setMultiple: function(canMultiple) {
			localStorage.setItem(this.multipleDef, canMultiple);
		},
		getMsgAlert: function() {
			var needMsgAlert = localStorage.getItem(this.msgAlertDef);
			return needMsgAlert == null || needMsgAlert == 'true';
		},
		setMsgAlert: function(needMsgAlert) {
			localStorage.setItem(this.msgAlertDef, needMsgAlert);
		},
		getNickName: function() {
			return localStorage.getItem(this.nickNameDef);
		},
		getPositionName: function() {
			var positionName = localStorage.getItem(this.positionNameDef);
			if (positionName == null) positionName = '';
			return positionName;
		},
		getMentor: function() {
			return localStorage.getItem(this.mentorDef);
		},
		getSubs: function() {
			return localStorage.getItem(this.subsDef);
		},
		getManageDepartment: function() {
			return localStorage.getItem(this.manageDepartmentDef);
		},
		getManageProject: function() {
			return localStorage.getItem(this.manageProjectDef);
		},
		getDepartmentId: function() {
			return localStorage.getItem(this.departmentIdDef);
		},
		getDepartmentName: function() {
			return localStorage.getItem(this.departmentNameDef);
		},
		getDepartments: function() {
			var departments = localStorage.getItem(this.departmentsDef);
			if (departments == null || departments == 'undefined') return [];
			return JSON.parse(departments);
		},
		getProjects: function() {
			var projects = localStorage.getItem(this.projectsDef);
			if (projects == null || projects == 'undefined') return [];
			return JSON.parse(projects);
		},
		getWcs: function() {
			var wcs = localStorage.getItem(this.wcsDef);
			if (wcs == null || wcs == 'undefined') return [];
			return JSON.parse(wcs);
		},
		getBizes: function() {
			var bizes = localStorage.getItem(this.bizesDef);
			if (bizes == null || bizes == 'undefined') return [];
			return JSON.parse(bizes);
		},
		getWarnRules: function() {
			var warnRules = localStorage.getItem(this.warnRulesDef);
			if (warnRules == null || warnRules == 'undefined') return {};
			return JSON.parse(warnRules);
		},
		getDict: function(key) {
			return localStorage.getItem(this.dictsPref + key);
		},
		getBillName: function(typeInt) {
			return localStorage.getItem(this.billsPref + typeInt);
		},
		containsModule: function(module) {
			return localStorage.getItem(this.modulePref + module) != null;
		},
		isLogin: function() {
			return this.getToken() != null;
		},
		cacheLogin: function(user) {
			var userDepartmentId = user.departmentId ? user.departmentId : -1;
			var userDepartmentName = user.departmentName ? user.departmentName : '';
			var userAccountId = user.accountId ? user.accountId : -1;
			var userAccountName = user.accountName ? user.accountName : '';
			var userAccountList = user.accountList ? user.accountList : [];
			localStorage.setItem(this.serverUrlDef, user.serverUrl);
			localStorage.setItem(this.serverNameDef, user.serverName);
			localStorage.setItem(this.tokenDef, user.token);
			localStorage.setItem(this.idDef, user.id);
			localStorage.setItem(this.nameDef, user.name);
			localStorage.setItem(this.accountIdDef, userAccountId);
			localStorage.setItem(this.accountNameDef, userAccountName);
			localStorage.setItem(this.accountListDef, userAccountList);
			localStorage.setItem(this.isGmDef, user.isGM);
			localStorage.setItem(this.isFmDef, user.isFM);
			localStorage.setItem(this.isHmDef, user.isHM);
			localStorage.setItem(this.isSmDef, user.isSM);

			if (user.permission) {
				localStorage.setItem(this.isFeeDmDef, user.permission.isFeeDM);
				localStorage.setItem(this.isFeePmDef, user.permission.isFeePM);
				localStorage.setItem(this.isHrDmDef, user.permission.isHrDM);
			}

			localStorage.setItem(this.nickNameDef, user.nickName);
			localStorage.setItem(this.positionNameDef, user.positionName ? user.positionName : '');
			localStorage.setItem(this.mentorDef, user.mentor);
			localStorage.setItem(this.subsDef, user.subs);
			localStorage.setItem(this.manageDepartmentDef, user.manageDepartment);
			localStorage.setItem(this.manageProjectDef, user.manageProject);

			var sv = '1.0.1';
			if (user.sv) {
				sv = user.sv;
			}
			localStorage.setItem(this.serverVersionDef, sv);

			localStorage.setItem(this.departmentIdDef, userDepartmentId);
			localStorage.setItem(this.departmentNameDef, userDepartmentName);
			var oldDepartments = user.departments,
				department;
			var departmentsHash = {},
				departments = [];
			for (var i = 0; i < oldDepartments.length; i++) {
				department = oldDepartments[i];
				if (!departmentsHash.hasOwnProperty(department.id)) {
					departmentsHash[department.id] = true;
					departments.push(department);
				}
			}
			localStorage.setItem(this.departmentsDef, JSON.stringify(departments));

			localStorage.setItem(this.projectsDef, JSON.stringify(user.projects));
			localStorage.setItem(this.wcsDef, JSON.stringify(user.wcs));
			localStorage.setItem(this.bizesDef, JSON.stringify(user.bizes));

			var warnRules = user.warnRules != undefined ? JSON.stringify(user.warnRules) : null;
			localStorage.setItem(this.warnRulesDef, warnRules);

			//字典
			for (var i = 0; i < user.dicts.length; i++) {
				localStorage.setItem(this.dictsPref + user.dicts[i].type, user.dicts[i].code);
			}

			//单据名称
			for (var i = 0; i < user.billNames.length; i++) {
				localStorage.setItem(this.billsPref + user.billNames[i].type, user.billNames[i].name);
			}

			//模块
			for (var i = 0; i < user.modules.length; i++) {
				localStorage.setItem(this.modulePref + user.modules[i], true);
			}
		},
		cleanCache: function(user) {
			//localStorage.removeItem(this.tokenDef);

			var serverUrl = localStorage.getItem(this.serverUrlDef);
			var serverName = localStorage.getItem(this.serverNameDef);
			var userName = localStorage.getItem(this.nameDef);
			var appVersion = localStorage.getItem(this.appVersionDef);

			var compress = localStorage.getItem(this.compressDef);
			var multiple = localStorage.getItem(this.multipleDef);
			var msgAlert = localStorage.getItem(this.msgAlertDef);

			localStorage.clear();

			localStorage.setItem(this.serverUrlDef, serverUrl);
			localStorage.setItem(this.serverNameDef, serverName);
			localStorage.setItem(this.nameDef, userName);
			localStorage.setItem(this.appVersionDef, appVersion);

			localStorage.setItem(this.compressDef, compress);
			localStorage.setItem(this.multipleDef, multiple);
			localStorage.setItem(this.msgAlertDef, msgAlert);
		},
		getGlobalIsBackCustomize: function() {
			var value = localStorage.getItem(this.globalIsBackCustomizeDef);
			return value != null && value == 'true';
		},
		setGlobalIsBackCustomize: function(isBackCustomize) {
			localStorage.setItem(this.globalIsBackCustomizeDef, isBackCustomize ? 'true' : 'false');
		},
		bindCustomizeBackEvent: function() {
			mj.setGlobalIsBackCustomize(true);
			window.addEventListener(event_trigger_custom_back, function(options) {
				mui.confirm('确认返回？', '确认返回', ['返回', '取消'], function(e) {
					if (e.index == 0) {
						mj.setGlobalIsBackCustomize(false);
						mui.back();

						//						var self = plus.webview.currentWebview();
						//						mui.fire(self.parent(), event_trigger_origin_back, {});
					}
				});
			});
		},
		backWithoutCustomize: function() {
			mj.setGlobalIsBackCustomize(false);
			mui.back();
		},
		backAndRefreshWithoutCustomize: function() {
			mj.setGlobalIsBackCustomize(false);
			mj.backAndRefresh();
		},
		showLogin: function(loginPath, callback) {
			var loginWebView = mui.preload({
				id: loginPath,
				url: loginPath,
				styles: {
					top: '0px',
					bottom: '0px'
				}
			});
			loginWebView.addEventListener('loaded', function() {
				loginWebView.show('slide-in-bottom', 500);
				callback && callback();
			}, false);
		},
		showLoading: function(msg) {
			plus.nativeUI.showWaiting(msg || '');
		},
		hideLoading: function() {
			plus.nativeUI.closeWaiting();
		},
		alert: function(msg, title, callback) {
			mui.alert(msg, title ? title : null, null, callback);
		},
		confirm: function(options, callback, falseCallback) {
			mui.confirm(options.msg || '确认删除', options.title || '系统提示', ['确认', '取消'], function(e) {
				if (e.index == 0) {
					callback && callback();
				} else {
					falseCallback && falseCallback();
				}
			});
		},
		prompt: function(option, callback) {
			mui.prompt(option.msg || '确认拒绝', option.prompt || '请输入拒绝理由', option.title || '系统提示', ['确认', '取消'], function(e) {
				if (e.index == 0) {
					if (e.value == '') {
						mui.toast(option.prompt || '请输入拒绝理由');
						return false;
					}
					callback && callback(e);
				}
			}, 'div')
			document.querySelector('.mui-popup-input input').type = 'text';
		},
		quit: {
			lastCall: new Date().getTime(),
			call: function() {
				var curTime = new Date().getTime();
				if (curTime - this.lastCall < 1000) {
					plus.runtime.quit();
				} else {
					this.lastCall = curTime;
					mui.toast('再按一次退出应用');
				}
			}
		},
		openWindowForA: function(domA, options) {
			var id = domA.getAttribute("href");
			var href = domA.href;
			mui.openWindow({
				id: id,
				url: href,
				styles: {
					popGesture: "close"
				},
				show: {
					aniShow: options && options.aniShow ? options.aniShow : 'slide-in-right'
				},
				waiting: {
					autoShow: options && options.autoShow ? options.autoShow : false
				}
			});
		},
		openWindow: function(href, id, options) {
			mui.openWindow({
				id: id ? id : href,
				url: href,
				styles: {
					popGesture: "close"
				},
				show: {
					aniShow: options && options.aniShow ? options.aniShow : 'slide-in-right'
				},
				waiting: {
					autoShow: options && options.autoShow ? options.autoShow : false
				},
				extras: options && options.extraOptions ? options.extraOptions : {}
			});
		},
		backAndRefresh: function() {
			var self = plus.webview.currentWebview();
			mui.fire(self.parent(), event_refresh_previous_page, {});
			mui.back();
		},
		backToHome: function() {
			var main1 = plus.webview.getWebviewById(view_temp_first_main);
			var main2 = plus.webview.getWebviewById(view_temp_second_main);
			var main3 = plus.webview.getWebviewById(view_temp_third_main);
			var main4 = plus.webview.getWebviewById(view_temp_fourth_main);
			main1.hide();
			main2.hide();
			main3.hide();
			main4.hide();
		},
		initPicker: function(data, tapId, showId, defaultValue, callback) {
			var self = this;
			var picker = new mui.PopPicker();
			picker.setData(data);
			var pickerButton = document.getElementById(tapId);
			var pickerShower = document.getElementById(showId);
			picker.mjCallback = callback;
			picker.pickerShower = pickerShower;
			pickerButton.addEventListener('tap', function(event) {
				picker.show(function(items) {
					self.selectPickerItem(items[0], picker);
				});
			}, false);
			if (defaultValue) {
				self.selectPickerValue(defaultValue, picker);
			}
			return picker;
		},
		selectPickerValue: function(value, picker, selectCallback) {
			picker.pickers[0].setSelectedValue(value);
			this.selectPickerItem(picker.pickers[0].getSelectedItem(), picker, selectCallback);
		},
		selectPickerItem: function(item, picker, selectCallback) {
			picker.pickerShower.innerText = item.text;
			picker.mjCallback && picker.mjCallback(item);
			selectCallback && selectCallback(item);
		},
		initDtPicker: function() {
			//具体到小时
			var timeSelects = mui('.time-select');
			timeSelects.each(function(i, timeSelect) {
				timeSelect.addEventListener('tap', function() {
					var objLi = this;
					var objTime = objLi.querySelector('.selected-time');
					var optionsJson = {
						value: objTime.innerText,
						beginYear: 2010,
						endYear: 2020
					};
					var picker = new mui.DtPicker(optionsJson);
					picker.show(function(rs) {
						objTime.innerText = rs.text;
						picker.dispose();
					});
				}, false);
			});
		},
		initMonthDtPicker: function(callback) {
			//具体到日（函数名称待修改）
			var timeSelects = mui('.time-select');
			timeSelects.each(function(i, timeSelect) {
				timeSelect.addEventListener('tap', function() {
					var objLi = this;
					var objTime = objLi.querySelector('.selected-time');
					var optionsJson = {
						type: "date",
						value: objTime.innerText,
						beginYear: 2010,
						endYear: 2020
					};
					var picker = new mui.DtPicker(optionsJson);
					picker.show(function(rs) {
						objTime.innerText = rs.text;
						picker.dispose();
						callback && callback();
					});
				}, false);
			});
		},
		initMonthsDtPicker: function() {
			//具体到月
			var timeSelects = mui('.time-select');
			timeSelects.each(function(i, timeSelect) {
				timeSelect.addEventListener('tap', function() {
					var objLi = this;
					var objTime = objLi.querySelector('.selected-time');
					var optionsJson = {
						type: "month",
						value: objTime.innerText,
						beginYear: 2010,
						endYear: 2020
					};
					var picker = new mui.DtPicker(optionsJson);
					picker.show(function(rs) {
						objTime.innerText = rs.text;
						picker.dispose();
					});
				}, false);
			});
		},
		initLimitDayDtPicker: function(callback) {
			//当月和上个月
			var timeSelects = mui('.limit-time-select');
			var lastMonthDate = new Date();
			lastMonthDate.setDate(1);
			lastMonthDate.setMonth(lastMonthDate.getMonth() - 1);
			timeSelects.each(function(i, timeSelect) {
				timeSelect.addEventListener('tap', function() {
					var objLi = this;
					var objTime = objLi.querySelector('.selected-limit-time');
					var optionsJson = {
						type: "date",
						value: objTime.innerText,
						beginYear: new Date().getFullYear(),
						beginDate: lastMonthDate,
						endDate: new Date()
					};
					var picker = new mui.DtPicker(optionsJson);
					picker.show(function(rs) {
						objTime.innerText = rs.text;
						picker.dispose();
						callback && callback();
					});
				}, false);
			});
		},
		initFutureDayDtPicker: function() {
			//今天以后
			var timeSelects = mui('.future-time-select');
			timeSelects.each(function(i, timeSelect) {
				timeSelect.addEventListener('tap', function() {
					var objLi = this;
					var objTime = objLi.querySelector('.selected-future-time');
					var optionsJson = {
						type: "date",
						value: objTime.innerText,
						beginYear: new Date().getFullYear(),
						beginDate: new Date()
					};
					var picker = new mui.DtPicker(optionsJson);
					picker.show(function(rs) {
						objTime.innerText = rs.text;
						picker.dispose();
					});
				}, false);
			});
		},
		initCyclePicker: function(callback) {
			return this.initPicker(
				[{
					value: 1,
					text: '日计划'
				}, {
					value: 2,
					text: '周计划'
				}, {
					value: 3,
					text: '月计划'
				}, {
					value: 4,
					text: '季计划'
				}, {
					value: 5,
					text: '年计划'
				}, {
					value: 6,
					text: '自定义'
				}],
				'showCycle',
				'taskCycle',
				1,
				function(pickData) {
					callback && callback(pickData.value);
				}
			);
		},
		changeCycle: function(cycle) {
			var start, end;
			var currentTime = new Date();
			switch (cycle) {
				case 1:
					start = currentTime.format('yyyy-MM-dd hh:00');
					end = currentTime.format('yyyy-MM-dd') + ' 18:00';
					break;
				case 2:
					start = currentTime.format('yyyy-MM-dd hh:00');
					end = getWeekEndDate() + ' 18:00';
					break;
				case 3:
					start = currentTime.format('yyyy-MM-dd hh:00');
					end = getMonthEndDate() + ' 18:00';
					break;
				case 4:
					start = currentTime.format('yyyy-MM-dd hh:00');
					end = getQuarterEndDate() + ' 18:00';
					break;
				case 5:
					start = currentTime.format('yyyy-MM-dd hh:00');
					end = getYearEndDate() + ' 18:00';
					break;
				case 6:
					break;
				default:
					start = currentTime.format('yyyy-MM-dd hh:00');
					end = currentTime.format('yyyy-MM-dd hh:00');
					break;
			}
			return {
				start: start,
				end: end
			}
		}
	};

	own.mj.forceLogout = function() {
		mj.hideLoading();
		getLaunchView(function(indexWebview) {
			mui.fire(indexWebview, event_force_logout, {});
		});
	}

	own.mj.cleanLogin = function() {
		mj.hideLoading();
		getLaunchView(function(indexWebview) {
			mui.fire(indexWebview, event_clean_login, {});
		});
	}

	own.mj.rpcErrHandler = function(xhr, type, e, errCallback) {
		switch (xhr.status) {
			case 403:
				mj.forceLogout();
				break;
			case 406:
				mui.confirm(xhr.responseText, '重要提醒', ['确定'], function() {});
				break;
			default:
				errCallback && errCallback(xhr, type, e);
				break;
		}
	}

	own.mj.jsonToQuery = function(obj) {
		return Object.keys(obj).map(function(key) {
			return key + '=' + obj[key]
		}).join('&');
	};

	own.mj.requestGet = function(url, jsonData, isCache, callback, errCallback, completeCallback) {
		mui.ajax({
			type: 'get',
			cache: isCache,
			dataType: 'json',
			timeout: 20000,
			url: mj.getServerUrl() + url,
			headers: {
				"ContentType": "application/x-www-form-urlencoded; charset=UTF-8",
				"Authorization": '' + mj.getToken(),
				"App-Version": '' + mj.getVersion()
			},
			data: jsonData,
			complete: function() {
				completeCallback && completeCallback();
			},
			success: function(data) {
				callback && callback(data);
			},
			error: function(xhr, type, e) {
				log("get xhr:" + JSON.stringify(xhr));
				log("get token:" + mj.getToken());
				log("get url:" + url);
				log("get data:" + JSON.stringify(jsonData));
				if (xhr.status && (xhr.status == 500 || xhr.status == 403 || xhr.status == 401 || xhr.status == 400)) {
					mj.rpcErrHandler(xhr, type, e, errCallback);
				} else {
					if (jsonData._retry < 2) {
						jsonData._retry++;
						setTimeout(function() {
							mj.requestGet(url, jsonData, isCache, callback, errCallback);
						}, 500);
					} else {
						mj.rpcErrHandler(xhr, type, e, errCallback);
					}
				}
			}
		});
	}

	own.mj.get = function(url, jsonData, callback, errCallback, completeCallback) {
		if (!jsonData) jsonData = {};
		jsonData._retry = 0;
		mj.requestGet(url, jsonData, true, callback, errCallback, completeCallback);
	}

	own.mj.freshGet = function(url, jsonData, callback, errCallback, completeCallback) {
		if (!jsonData) jsonData = {};
		jsonData._retry = 0;
		mj.requestGet(url, jsonData, false, callback, errCallback, completeCallback);
	}

	own.mj.requestPost = function(url, jsonData, isJson, callback, errCallback, completeCallback) {
		var postData = isJson ? jsonData : JSON.stringify(jsonData);
		mui.ajax({
			type: "post",
			//dataType: "json",
			contentType: "application/json;charset=UTF-8",
			url: mj.getServerUrl() + url,
			headers: {
				"Authorization": '' + mj.getToken(),
				"App-Version": '' + mj.getVersion()
			},
			data: postData,
			complete: function() {
				completeCallback && completeCallback();
			},
			success: function(collection, response, options) {
				callback && callback(collection, response, options);
			},
			error: function(xhr, type, e) {
				log("post token:" + mj.getToken());
				log("post url:" + url);
				log("post data:" + JSON.stringify(jsonData));
				if (xhr.status && (xhr.status == 500 || xhr.status == 403 || xhr.status == 401 || xhr.status == 400)) {
					mj.rpcErrHandler(xhr, type, e, errCallback);
				} else {
					if (jsonData._retry < 2) {
						jsonData._retry++;
						setTimeout(function() {
							mj.requestPost(url, jsonData, isJson, callback, errCallback, completeCallback);
						}, 500);
					} else {
						mj.rpcErrHandler(xhr, type, e, errCallback);
					}
				}
			}
		});
	}

	own.mj.post = function(url, jsonData, callback, errCallback, completeCallback) {
		if (!jsonData) jsonData = {};
		jsonData._retry = 0;
		mj.requestPost(url, jsonData, false, callback, errCallback, completeCallback);
	}

	own.mj.postJson = function(url, jsonData, callback, errCallback, completeCallback) {
		if (!jsonData) jsonData = {};
		jsonData._retry = 0;
		mj.requestPost(url, jsonData, true, callback, errCallback, completeCallback);
	}

	own.mj.requestPostForm = function(url, jsonData, callback, errCallback, completeCallback) {
		var postData = mj.jsonToQuery(jsonData);
		mui.ajax({
			type: "post",
			//dataType: "json",
			//contentType: "application/json;charset=UTF-8",
			url: mj.getServerUrl() + url,
			headers: {
				"Authorization": '' + mj.getToken(),
				"App-Version": '' + mj.getVersion()
			},
			data: postData,
			complete: function() {
				completeCallback && completeCallback();
			},
			success: function(collection, response, options) {
				callback && callback(collection, response, options);
			},
			error: function(xhr, type, e) {
				log("post token:" + mj.getToken());
				log("post url:" + url);
				log("post data:" + JSON.stringify(jsonData));
				if (xhr.status && (xhr.status == 500 || xhr.status == 403 || xhr.status == 401 || xhr.status == 400)) {
					mj.rpcErrHandler(xhr, type, e, errCallback);
				} else {
					if (jsonData._retry < 2) {
						jsonData._retry++;
						setTimeout(function() {
							mj.requestPostForm(url, jsonData, callback, errCallback, completeCallback);
						}, 500);
					} else {
						mj.rpcErrHandler(xhr, type, e, errCallback);
					}
				}
			}
		});
	}

	own.mj.postForm = function(url, jsonData, callback, errCallback, completeCallback) {
		if (!jsonData) jsonData = {};
		jsonData._retry = 0;
		mj.requestPostForm(url, jsonData, callback, errCallback, completeCallback);
	}

	own.mj.reload = function(force) {
		document.location.reload(force || true);
	}

	own.mj.checkLoginInfo = function(callback) {
		mui.ajax({
			type: "post",
			contentType: "application/json;charset=UTF-8",
			url: mj.getServerUrl() + '/api/m/user/check-login',
			headers: {
				"Authorization": '' + mj.getToken(),
				"App-Version": '' + mj.getVersion()
			},
			data: JSON.stringify({}),
			success: function(collection, response, options) {
				callback(true);
			},
			error: function(xhr, type, e) {
				if (xhr.status == 403) {
					callback(false);
				} else {
					log("checkLoginInfo(" + xhr.status + "):" + JSON.stringify(xhr));
					callback(true);
				}
			}
		});
	}

	own.mj.enableBtn = function(btn, txt) {
		if (txt) btn.innerText = txt;
		btn.removeAttribute('disabled');
	}

	own.mj.disableBtn = function(btn, txt) {
		if (txt) btn.innerText = txt;
		btn.setAttribute('disabled', 'disabled');
	}

	own.mj.inputMoveToEnd = function(boxSelector, itemSelector) {
		mui(boxSelector).on('tap', itemSelector, function() {
			this.selectionStart = this.selectionEnd = this.value.length;
		});
	}

	own.mj.fixAfterInput = function() {
		document.activeElement.blur();
	}

	own.mj.fixScrollTop = function(scrollHeight) {
		document.body.scrollTop = document.documentElement.scrollTop = scrollHeight;
	}

	own.mj.scrollToTop = function() {
		mj.fixScrollTop(0);
	}

	own.mj.showModal = function(selector) {
		document.getElementById(selector).classList.add('mui-active');
	}

	own.mj.hideModal = function(selector) {
		document.getElementById(selector).classList.remove('mui-active');
	}

	own.mj.throttle = function(delay, action, tail, debounce) {
		var now = Date.now,
			last_call = 0,
			last_exec = 0,
			timer = null,
			curr, diff,
			ctx, args, exec = function() {
				last_exec = now();
				action.apply(ctx, args);
			};

		return function() {
			ctx = this, args = arguments,
				curr = now(), diff = curr - (debounce ? last_call : last_exec) - delay;

			clearTimeout(timer);

			if (debounce) {
				if (tail) {
					timer = setTimeout(exec, delay);
				} else if (diff >= 0) {
					exec();
				}
			} else {
				if (diff >= 0) {
					exec();
				} else if (tail) {
					timer = setTimeout(exec, -diff);
				}
			}
			last_call = curr;
		}
	}

	own.mj.debounce = function(idle, action, tail) {
		return mj.throttle(idle, action, tail, true);
	}

	own.mj.allView = function() {
		var all = plus.webview.all();
		for (var i = 0, len = all.length; i < len; i++) {
			log('viewId:' + all[i].id);
		}
	}

	own.mj.refreshViewOfMine = function() {
		var mineEntryWebview = plus.webview.getWebviewById(view_mine_entry_id);
		mui.fire(mineEntryWebview, event_refresh_mine_entry, {});
	}

	own.mj.refreshViewOfMineName = function() {
		var mineEntryWebview = plus.webview.getWebviewById(view_mine_entry_id);
		mui.fire(mineEntryWebview, event_refresh_mine_name, {});
	}

	own.mj.propertyGetMethod = function(obj, property) {
		if (obj && obj.get) {
			return obj.get(property);
		} else {
			return obj[property];
		}
	}

	own.mj.splitAccountItem = function(data, accountId, callback) {
		mui.each(data, function(index, item) {
			if (item.accountId == accountId) {
				callback && callback(item);
			}
		});
	}

	own.mj.splitCCItemByAccount = function(data, accountId, callback) {
		mui.each(data, function(index, item) {
			if (item.accountId == accountId || item.accountId == 0) {
				callback && callback(item);
			}
		});
	}

	own.mj.splitCashFlowItem = function(data, cashFlowItem, callback) {
		mui.each(data, function(dataIndex, dataItem) {
			if (dataItem.item == cashFlowItem) {
				callback && callback(dataItem);
			}
		});
	}

	own.mjQueryMsgByType = function(msgType, parameters, callback) {
		var pageSize = parameters.pageSize;
		var pageNum = parameters.pageNum;
		mj.get(MJ_URL.MSG_TYPE.mjFormat(msgType), {
			pageSize: pageSize,
			pageNum: pageNum
		}, function(o) {
			if (o && o.status == SYSTEM_SUCCEED) {
				callback && callback(o.data);
			} else {
				mui.toast(LOST_NETWORK_CONNECTION);
				callback && callback(false);
			}

		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
			callback && callback(false);
		});
	}

	//所有部门
	own.mjQueryDepartments = function(callback) {
		mj.get(MJ_URL.DEPT_API, {}, function(d) {
			callback && callback(d.data);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//员工部门
	own.mjQueryDepartmentsByUser = function(callback) {
		mj.get(MJ_URL.DEPT_LIST_BY_ME, {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	own.mjQueryDepartmentsByMgr = function(callback) {
		mj.get(MJ_URL.DEPT_LIST_BY_MGR, {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//权限部门
	own.mjQueryDepartmentsByPermission = function(opt, callback, errCallback) {
		var params = {};
		params.mm = opt.mm;
		params.t1 = opt.t1;
		mj.get(MJ_URL.DEPT_LIST_BY_PERMISSION, params, function(res) {
			if (res && res.status == SYSTEM_SUCCEED) {
				callback && callback(res.data);
			} else {
				showFromCode(res.status);
			}
		}, errCallback);
	}

	//部门人力权限
	own.mjQueryDepartmentsByReportPermissionForHr = function(callback, errCallback) {
		mjQueryDepartmentsByPermission({
			mm: SYSTEM_MODULE_HR,
			t1: 'report'
		}, callback, errCallback);
	}

	//部门费用权限
	own.mjQueryDepartmentsByFeePermissionForFin = function(callback, errCallback) {
		mjQueryDepartmentsByPermission({
			mm: SYSTEM_MODULE_FIN,
			t1: 'fee'
		}, callback, errCallback);
	}

	//本人参与的项目
	own.mjQueryProjectsJoined = function(callback) {
		mj.get(MJ_URL.PROJ_LIST_JOINED, {}, function(d) {
			callback && callback(d.rows);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	// 全部项目
	own.mjQueryAllProjects = function(projectType, callback) {
		mj.get(MJ_URL.PROJ_LIST_ALL.mjFormat(projectType), {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//权限项目
	own.mjQueryProjectsByPermission = function(opt, callback, errCallback) {
		var params = {};
		params.mm = opt.mm;
		params.t1 = opt.t1;
		params.pt = opt.pt || PROJECT_TYPE_ALL;
		mj.get(MJ_URL.PROJ_LIST_PERMISSION, params, function(res) {
			if (res && res.status == SYSTEM_SUCCEED) {
				callback && callback(res.data);
			} else {
				showFromCode(res.status);
			}
		}, errCallback);
	}

	//人力报表项目
	own.mjQueryPtAllProjectsByReportPermissionForHr = function(callback, errCallback) {
		mjQueryProjectsByPermission({
			mm: SYSTEM_MODULE_HR,
			t1: 'report',
			pt: PROJECT_TYPE_ALL
		}, callback, errCallback);
	}

	//财务费用项目
	own.mjQueryPtAllProjectsByFeePermissionForFin = function(callback, errCallback) {
		mjQueryProjectsByPermission({
			mm: SYSTEM_MODULE_FIN,
			t1: 'fee',
			pt: PROJECT_TYPE_ALL
		}, callback, errCallback);
	}

	//员工关联任务
	own.mjQueryTasksByUser = function(callback) {
		mj.freshGet(MJ_URL.TASK_LIST_BY_ME, {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//员工银行账号
	own.mjQueryBankByUser = function(userId, callback) {
		mj.get(MJ_URL.BA_LIST_BY_USER.mjFormat(userId), {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//供应商银行账号
	own.mjQueryBankByCustomer = function(customerId, callback) {
		mj.get(MJ_URL.BA_LIST_BY_SUPPLIER.mjFormat(customerId), {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//客户银行账号
	own.mjQueryBankByConsumer = function(consumerId, callback) {
		mj.get(MJ_URL.BA_LIST_BY_CONSUMER.mjFormat(consumerId), {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//全部会计科目
	own.mjQueryEas = function(params, callback, errCallback) {
		mj.get(MJ_URL.EA_API, params, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//项目费用科目
	own.mjQueryExpenseAccountsByProject = function(projectId, userId, billFor, callback, errCallback) {
		mj.get(MJ_URL.EA_LIST_BY_PROJ.mjFormat(projectId), {
			userId: userId,
			billFor: billFor
		}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}
	//部门费用科目
	own.mjQueryExpenseAccountsByDepartment = function(departmentId, userId, billFor, callback, errCallback) {
		mj.get(MJ_URL.EA_LIST_BY_DEPT.mjFormat(departmentId), {
			userId: userId,
			billFor: billFor
		}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//借款-预付类型
	own.mjQuerySupplierPrepayDrs = function(params, callback) {
		mj.get(MJ_URL.EA_BILL_LOAN_DR, params, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//供应商付货款单-应付账款
	own.mjQuerySupplierPayGoodDrs = function(params, callback) {
		mj.get(MJ_URL.EA_BILL_PAYGOODS_DR, params, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//销售单-借方科目
	own.mjQuerySaleDrs = function(params, callback) {
		mj.get(MJ_URL.EA_BILL_SALE_DR, params, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//资产类型
	own.mjQuerySupplierAssets = function(params, callback) {
		mj.get(MJ_URL.EA_BILL_ASSET, params, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//收入类型
	own.mjQuerySaleCrs = function(params, callback) {
		mj.get(MJ_URL.EA_BILL_SALE_CR, params, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//收款单借方科目
	own.mjQueryCollectionDrs = function(params, callback) {
		mj.get(MJ_URL.EA_BILL_COLLECTION_DR, params, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//收款类型
	own.mjQueryCollectionCrs = function(params, callback) {
		mj.get(MJ_URL.EA_BILL_COLLECTION_CR, params, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//领料单贷方科目
	own.mjQueryMaterialReqCrs = function(params, callback) {
		mj.get(MJ_URL.EA_BILL_MATERIAL_CR, params, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//进项税科目
	own.mjQueryTaxEas = function(params, callback) {
		mj.get(MJ_URL.EA_BILL_TAX, params, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//销项税科目
	own.mjQueryOutputTaxEas = function(params, callback) {
		mj.get(MJ_URL.EA_BILL_OUT_TAX, params, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//供应商
	own.mjQueryCustomers = function(callback) {
		mj.get(MJ_URL.SPL_API, {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//所有客户
	own.mjQueryAllConsumers = function(callback) {
		mj.get(MJ_URL.CC_LIST_ALL, {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//权限客户
	own.mjQueryConsumersByPermission = function(opt, callback, errCallback) {
		var params = {};
		params.mm = opt.mm;
		params.t1 = opt.t1;
		mj.get(MJ_URL.CC_LIST_BY_PERMISSION, params, function(res) {
			if (res && res.status == SYSTEM_SUCCEED) {
				callback && callback(res.data);
			} else {
				showFromCode(res.status);
			}
		}, errCallback);
	}

	//客户类别
	own.mjQueryConsumerCategories = function(callback) {
		mj.get(MJ_URL.CC_CATEGORY_API, {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//客户性质
	own.mjQueryConsumerCharacters = function(callback) {
		mj.get(MJ_URL.CC_CHARACTER_API, {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//客户类型
	own.mjQueryConsumerTypes = function(callback) {
		mj.get(MJ_URL.CC_TYPE_API, {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//客户信息来源
	own.mjQueryConsumerInfoSources = function(callback) {
		mj.get(MJ_URL.CC_INFO_API, {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//客户行业
	own.mjQueryConsumerProfessions = function(callback) {
		mj.get(MJ_URL.CC_PROFESSION_API, {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//客户部门
	own.mjQueryConsumerDepartments = function(callback) {
		mj.get(MJ_URL.CC_DEPT_API, {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//联系人联系类型
	own.mjQueryConsumerContactTypes = function(callback) {
		mj.get(MJ_URL.CC_CT_API, {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//保护状态
	own.mjQueryConsumerProtectStatus = function(callback) {
		mj.get(MJ_URL.CC_PROTECT_API, {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//销售状态
	own.mjQueryConsumerSaleStatus = function(callback) {
		mj.get(MJ_URL.CC_SS_API, {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//国家
	own.mjQueryCities = function(callback) {
		mj.get(MJ_URL.CITY_API, {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//部门业务活动
	own.mjQueryBusinessesByDepartment = function(departmentId, callback) {
		mj.get(MJ_URL.BIZ_LIST_BY_DEPT.mjFormat(departmentId), {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//员工业务活动
	own.mjQueryBusinessesByUser = function(userId, callback) {
		mj.get(MJ_URL.BIZ_LIST_BY_USER.mjFormat(userId), {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//员工工作内容
	own.mjQueryWcsByUser = function(userId, callback) {
		mj.get(MJ_URL.WC_LIST_BY_USER.mjFormat(userId), {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//车辆
	own.mjQueryAllCars = function(callback) {
		mj.get(MJ_URL.CAR_API, {}, function(d) {
			callback && callback(d.data);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//产品
	own.mjQueryProducts = function(callback) {
		mj.get(MJ_URL.PRODUCT_API, {}, function(d) {
			callback && callback(d.data);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//帐套
	own.mjQueryAllAccountBooks = function(callback) {
		mj.get(MJ_URL.AB_LIST_ALL, {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//币别
	own.mjQueryCurrencies = function(callback) {
		mj.get(MJ_URL.CURRENCY_API, {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//现金流量项目
	own.mjQueryCashFlows = function(callback) {
		mj.get(MJ_URL.CASH_FLOW_API, {}, function(d) {
			callback && callback(d);
		}, function(xhr) {
			showResult(xhr, LOST_NETWORK_CONNECTION);
		});
	}

	//单页
	own.initSelectView = function(viewWrapperId, defaultPageId, beforeShowCallback) {
		var viewApi = mui('#' + viewWrapperId).view({
			defaultPage: '#' + defaultPageId
		});
		var view = viewApi.view;
		var oldBack = mui.back;
		mui.back = function() {
			if (viewApi.canBack()) {
				viewApi.back();
			} else {
				oldBack();
			}
		};

		beforeShowCallback && function() {
			view.addEventListener('pageBeforeShow', function(e) {
				beforeShowCallback(e.detail.page.id);
			});
		}();
	}

	own.findById = function(id, list) {
		var findResult = undefined;
		mui.each(list, function(index, item) {
			if (item.id == id) {
				findResult = item;
				return false;
			}
		});
		return findResult;
	}

	//事件冒泡
	own.suspendEventBub = function(eve) {
		var e = eve || window.event;
		if (e && e.stopPropagation) {
			e.stopPropagation();
		} else {
			e.cancelBubble = true;
		}
	}

	own.mj.readMsg = function(msgId) {
		setTimeout(function() {
			mj.post(MJ_URL.MSG_ITEM_READ.mjFormat(msgId), {}, function() {}, function() {});
		}, 10);
	}

	own.mj.pageScroll = function() {
		var deceleration = mui.os.ios ? 0.0003 : 0.0009;
		mui('.mui-scroll-wrapper').scroll({
			bounce: false,
			indicators: true,
			deceleration: deceleration
		});
	}

	own.mj.initPullToRefreshControl = function(selector, pullDownCallback, pullUpCallback) {
		return mui(selector).pullToRefresh({
			down: {
				auto: false,
				callback: function() {
					var self = this;
					self.refresh(true);
					pullDownCallback && pullDownCallback(self);
				}
			},
			up: {
				auto: false,
				callback: function() {
					var self = this;
					pullUpCallback && pullUpCallback(self);
				}
			}
		});
	}

	own.mj.inputText = function() {
		mui('.mui-content').on('input', 'textarea', function() {
			this.style.height = this.scrollHeight + 'px'
		});
	}

	own.mj.splitWith = function(str, len) {
		var relVal = '';
		if (str == undefined) {
			return false;
		}

		var splitIndex = 0;
		for (var i = 0; i < str.length; i++, splitIndex++) {
			if (splitIndex == len) {
				relVal += '\n';
				splitIndex = 0;
			}
			relVal += str[i];
		}
		return relVal;
	}

	own.mj.showNoneBillView = function($container) {
		var itemHtml =
			'<div class="none-img-wrapper"><div class="none-img"><img src="../../@/img/noneImg/none_data.png"><div class="none-img-tip">暂无任何单据</div></div></div>';
		$container.innerHTML = itemHtml;
	}

	own.mj.showNoneOwnDailylogView = function($container) {
		var itemHtml =
			'<div class="none-img-wrapper"><div class="none-img"><img src="../../@/img/noneImg/bind_action.png"><div class="none-img-tip">点击右上角的"+",填写今天的日报吧</div></div></div>';
		$container.innerHTML = itemHtml;
	}

	own.mj.showNoneDataView = function($container) {
		var itemHtml =
			'<div class="none-img-wrapper"><div class="none-img"><img src="../../@/img/noneImg/none_data.png"><div class="none-img-tip">暂无任何数据</div></div></div>';
		$container.innerHTML = itemHtml;
	}

	own.mj.showNoneNewsView = function($container) {
		var itemHtml =
			'<div class="none-img-wrapper"><div class="none-img"><img src="../../@/img/noneImg/none_news.png"><div class="none-img-tip">暂无任何消息传来</div></div></div>';
		$container.innerHTML = itemHtml;
	}

	own.mj.showNoneChartView = function($container) {
		var itemHtml =
			'<div class="none-img-wrapper" style="position:static"><div class="none-img"><img src="../../@/img/noneImg/none_data.png"><div class="none-img-tip">此区间无数据</div></div></div>';
		$container.innerHTML = itemHtml;
	}

	own.mj.showNullDimensionView = function($container) {
		var itemHtml =
			'<div class="none-img-wrapper"><div class="none-img"><img src="../../@/img/noneImg/bind_action.png"><div class="none-img-tip">请选择数据维度</div></div></div>';
		$container.innerHTML = itemHtml;
	}

	own.mj.getUserCurrentLocation = function(selector, callback) {
		plus.geolocation.getCurrentPosition(function(p) {
			var addrGCj = GPS.gcj_encrypt(p.coords.latitude, p.coords.longitude);
			var addrWGS = GPS.gcj_decrypt_exact(addrGCj['lat'], addrGCj['lon']);
			var lnglatXY = mui.os.ios ? new AMap.LngLat(addrGCj['lon'], addrGCj['lat']) : new AMap.LngLat(addrWGS['lon'],
				addrWGS['lat']);
			var latitute;
			var longitude;
			var currentAddr;

			var geocoder = new AMap.Geocoder({
				radius: 50
			});

			geocoder.getAddress(lnglatXY, function(status, result) {
				if (status === 'complete' && result.info === 'OK') {
					currentAddr = result.regeocode.formattedAddress;
					latitute = lnglatXY.getLat();
					longitude = lnglatXY.getLng();
					document.getElementById(selector).innerText = result.regeocode.formattedAddress;

					callback && callback(currentAddr, longitude, latitute);
				} else {
					mui.toast(LOST_NETWORK_CONNECTION);
				}
			});
		}, function(e) {
			switch (e.code) {
				case e.PERMISSION_DENIED:
					mui.toast('访问权限被拒绝.');
					break;
				case e.POSITION_UNAVAILABLE:
					mui.toast('位置信息不可用.');
					break;
				case e.TIMEOUT:
					mui.toast('获取位置信息超时.');
					break;
				case e.UNKNOWN_ERROR:
				default:
					mui.toast('获取位置错误:' + e.code);
					break;
			}
		}, {
			geocode: true,
			provider: 'amap'
		});
	}
	////附件

	own.imgFilter =
		/^(?:image\/bmp|image\/cis\-cod|image\/gif|image\/ief|image\/jpeg|image\/jpeg|image\/jpeg|image\/pipeg|image\/png|image\/svg\+xml|image\/tiff|image\/x\-cmu\-raster|image\/x\-cmx|image\/x\-icon|image\/x\-portable\-anymap|image\/x\-portable\-bitmap|image\/x\-portable\-graymap|image\/x\-portable\-pixmap|image\/x\-rgb|image\/x\-xbitmap|image\/x\-xpixmap|image\/x\-xwindowdump)$/i;

	own.prepareUpload = function(btnAddSelector, attachWrapperId, uploadModule, refId, uploadUrl, deleteUrl, needCompress,
		canMultiple) {
		//选取图片的来源，拍照和相册 
		document.querySelector(btnAddSelector).addEventListener('tap', function() {
			var actionbuttons = [{
				title: "拍照"
			}, {
				title: "相册选取"
			}];
			var actionstyle = {
				title: "选择照片",
				cancel: "取消",
				buttons: actionbuttons
			};
			plus.nativeUI.actionSheet(actionstyle, function(e) {
				if (e.index == 1) {
					getImageFromCapture(function(fileUrl, fileName) {
						if (needCompress) {
							compressAndUploadAttach(fileUrl, fileName, uploadModule, refId, uploadUrl, attachWrapperId);
						} else {
							mjUploadAttach(fileUrl, fileName, uploadModule, refId, uploadUrl, attachWrapperId);
						}
					});
				} else if (e.index == 2) {
					getImageFromGallery(canMultiple, function(fileUrl, fileName) {
						if (needCompress) {
							compressAndUploadAttach(fileUrl, fileName, uploadModule, refId, uploadUrl, attachWrapperId);
						} else {
							mjUploadAttach(fileUrl, fileName, uploadModule, refId, uploadUrl, attachWrapperId);
						}
					});
				}
			});
		});

		mj.deletAttachItem(attachWrapperId, deleteUrl);
	}

	own.prepareUploadImgFromCapture = function(btnAddSelector, attachWrapperId, uploadModule, refId, uploadUrl, deleteUrl,
		needCompress, canMultiple) {
		document.querySelector(btnAddSelector).addEventListener('tap', function() {
			getImageFromCapture(function(fileUrl, fileName) {
				if (needCompress) {
					compressAndUploadAttach(fileUrl, fileName, uploadModule, refId, uploadUrl, attachWrapperId);
				} else {
					mjUploadAttach(fileUrl, fileName, uploadModule, refId, uploadUrl, attachWrapperId);
				}
			});
		});

		mj.deletAttachItem(attachWrapperId, deleteUrl);
	}

	own.mj.upload = function(fileUrl, fileName, refModule, refId, refUrl, callback) {
		var attachs = plus.uploader.createUpload(mj.getServerUrl() + refUrl, {
			method: 'POST'
		}, function(t, status) {
			if (status == 200) {
				mj.hideLoading();
				var result = JSON.parse(t.responseText);
				if (result.flag == 1) {
					mui.toast("上传成功");
					callback && callback(result.data.id);
				} else {
					mui.toast("上传失败");
				}
			} else {
				mui.toast('上传失败' + status);
			}
		});

		attachs.setRequestHeader('Authorization', mj.getToken());
		attachs.setRequestHeader('App-Version', mj.getVersion());
		attachs.addFile(fileUrl, {
			key: 'file'
		});
		attachs.addData("refId", refId.toString());
		attachs.addData("refModule", refModule);

		attachs.start();
	}

	own.mj.deletAttachItem = function(attachWrapperId, deleteUrl) {
		mui('#' + attachWrapperId).on('tap', '.attach-del', function() {
			var div = this.parentNode;
			var attachId = div.getAttribute('pid');
			var fixedDeleteUrl = deleteUrl + '?id=' + attachId;
			mui.confirm('确认删除该附件？', '删除附件', ['确认', '取消'], function(e) {
				if (e.index == 0) {
					mj.post(fixedDeleteUrl, {
						id: attachId
					}, function(d) {
						div.parentNode.removeChild(div);
					}, function(xhr) {});
				}
			});
		});
	}

	function compressAndUploadAttach(fileUrl, fileName, uploadModule, refId, uploadUrl, attachWrapperId) {
		compressImage(fileUrl, fileName, function(path, event) {
			var imgDiv = showAttachImg(event.target, attachWrapperId);
			mj.upload(event.target, fileName, uploadModule, refId, uploadUrl, function(attachId) {
				attaches.push(attachId);
				imgDiv.setAttribute('pid', attachId);
			});
		});
	}

	//Deprecated
	own.mjResetAttach = function(attachWrapperId) {
		attaches = [];

		var container = document.getElementById(attachWrapperId);
		for (var i = container.childNodes.length; i > 1; i--) {
			var node = container.childNodes[i - 1];
			if (node.nodeType === 1) {
				container.removeChild(node);
			}
		}
	}

	function mjUploadAttach(fileUrl, fileName, uploadModule, refId, uploadUrl, attachWrapperId) {
		var imgDiv = showAttachImg(fileUrl, attachWrapperId);
		mj.upload(fileUrl, fileName, uploadModule, refId, uploadUrl, function(attachId) {
			attaches.push(attachId);
			imgDiv.setAttribute('pid', attachId);
		});
	}

	//相册选取
	function getImageFromGallery(canMultiple, callback) {
		plus.gallery.pick(function(e) {
			var zm = 0;
			setTimeout(prepareFile, 200);

			function prepareFile() {
				if (canMultiple) {
					plus.io.resolveLocalFileSystemURL(e.files[zm], function(entry) {
						callback && callback(entry.toLocalURL(), entry.name);
					}, function(e) {
						plus.nativeUI.toast("读取相册文件错误：" + e.message);
					});
					zm++;
					if (zm < e.files.length) {
						setTimeout(prepareFile, 200);
					}
				} else {
					plus.io.resolveLocalFileSystemURL(e, function(entry) {
						callback && callback(entry.toLocalURL(), entry.name);
					}, function(e) {
						plus.nativeUI.toast("读取相册文件错误：" + e.message);
					});
				}
			}
		}, function(e) {
			//log("取消选择图片");
		}, {
			filter: "image",
			multiple: canMultiple
		});
	}

	// 拍照  
	function getImageFromCapture(callback) {
		var cmr = plus.camera.getCamera();
		cmr.captureImage(function(p) {
			plus.io.resolveLocalFileSystemURL(p, function(entry) {
				callback && callback(entry.toLocalURL(), entry.name);
			}, function(e) {
				plus.nativeUI.toast("读取拍照文件错误：" + e.message);
			});
		}, function(e) {}, {
			index: 1
		});
	}

	//压缩图片  
	function compressImage(url, filename, callback) {
		var name = "_downloads/upload/" + filename;
		plus.zip.compressImage({
			src: url, //src: (String 类型 )压缩转换原始图片的路径
			dst: name, //压缩转换目标图片的路径
			quality: 20, //quality: (Number 类型 )压缩图片的质量.取值范围为1-100
			overwrite: true //overwrite: (Boolean 类型)覆盖生成新文件
		}, function(event) {
			//event.target获取压缩转换后的图片url路
			callback && callback(name, event);
		}, function(error) {
			plus.nativeUI.toast("压缩图片失败，请稍候再试");
		});
	}

	//压缩图片后显示
	own.showAttachImg = function(url, attachWrapperId, attachId) {
		//      var waiting = plus.nativeUI.showWaiting();
		//      name=name.substring(0,name.indexOf("."));
		var imgSrc = 'src="' + url + '"';
		var imgDiv = document.createElement('div');
		if (attachId) {
			imgDiv.setAttribute("pid", attachId);
		}
		imgDiv.className = 'attach-list-item';
		imgDiv.innerHTML = '    <img style="width:100%;height:100%;" data-preview-src="" data-preview-group="1" ' + imgSrc +
			'/>' +
			'    <span class="attach-del">' +
			'        <div class="mui-icon iconfont icon-baoxiaomingxi-jian"></div>' +
			'    </span>';
		document.getElementById(attachWrapperId).appendChild(imgDiv);
		return imgDiv;
		//waiting.close();
	}

	own.mj.getLocalImgUrl = function(entry,relativeStorePath){
		var localImgUrl;
		if(window.plus.os.name === 'iOS') {
			localImgUrl = entry.__remoteURL__;
		}else {
			localImgUrl = relativeStorePath;
		}
		return localImgUrl;
	}

	own.mj.download = function(relativeDownUrl, relativeStorePath, callback) {
		relativeDownUrl = mj.getServerUrl() + relativeDownUrl;
		var dtask = plus.downloader.createDownload(relativeDownUrl, {
			filename: relativeStorePath
		}, function(d, status) {
			if (status == 200) {
				callback && callback(true);
			} else {
				log("下载失败:" + status + "," + relativeStorePath);
				dtask.abort();
				if (relativeStorePath != null) {
					plus.io.resolveLocalFileSystemURL(relativeStorePath, function(entry) {
						entry.remove(function(entry) {
							//		       log("文件删除成功," + relativeStorePath);
						}, function(e) {
							log("文件删除失败," + relativeStorePath);
						});
					});
				}
				callback && callback(false);
			}
		});
		dtask.setRequestHeader('Authorization', mj.getToken());
		dtask.setRequestHeader('App-Version', mj.getVersion());
		dtask.start();
	}

	own.setImgFromLocal = function(relativePath, imgName, attachWrapper, attachId) {
		var imgUrl = plus.io.convertLocalFileSystemURL(relativePath);
		return showAttachImg(imgUrl, attachWrapper, attachId);
	}

	function setImgFromNet(loadUrl, relativePath, imgName, attachWrapper, attachId) {
		mj.download(loadUrl, relativePath, function(succeed) {
			if (succeed) {
				var imgUrl = plus.io.convertLocalFileSystemURL(relativePath);
				if(window.plus.os.name === 'iOS') {
					plus.io.resolveLocalFileSystemURL(relativePath, function(entry) {
						imgUrl = mj.getLocalImgUrl(entry,relativePath);
						showAttachImg(imgUrl, attachWrapper, attachId);
					},undefined);
				}else {
					showAttachImg(imgUrl, attachWrapper, attachId);
				}
			}
		});
	}

	own.doGetAttach = function(loadUrl, relativePath, imgName, attachWrapper, attachId, callback) {
		plus.io.resolveLocalFileSystemURL(relativePath, function(entry) {
			var localImgUrl = mj.getLocalImgUrl(entry,relativePath);
			var imgDom = setImgFromLocal(localImgUrl, imgName, attachWrapper, attachId);
			callback && callback(imgDom);
		}, function(e) {
			log("图片不存在,联网下载=" + relativePath);

			setTimeout(function() {
				setImgFromNet(loadUrl, relativePath, imgName, attachWrapper, attachId);
			}, 50);
		});
	}

	////附件结束


	//通用控件
	own.initDepartmentSelect = function(
		hasSpecial,
		nullMine,
		nullSub,
		isUser,
		isCuetomer,
		isFeeOwner,
		isFeeBiz,
		isFeeWc,
		departmentCellId,
		departmentNameShowId,
		departmentPageId,
		departmentParentBtnId,
		departmentParentTitleId,
		departmentsWrapperId,
		departmentConfirmBtnId,
		departmentChangeCallback,
		getCurrentDepartmentCallback
	) {
		setTimeout(function() {
			mjQueryDepartments(function(data) {
				departments = data;

				bindDepartmentEvents(
					false,
					hasSpecial,
					nullMine,
					nullSub,
					isUser,
					isCuetomer,
					isFeeOwner,
					isFeeBiz,
					isFeeWc,
					departmentCellId,
					departmentNameShowId,
					departmentPageId,
					departmentParentBtnId,
					departmentParentTitleId,
					departmentsWrapperId,
					departmentConfirmBtnId,
					departmentChangeCallback,
					getCurrentDepartmentCallback
				);
			});
		}, 100);
	}

	own.checkTreeRoots = function(items) {
		var rootMap = {};
		mui.each(items, function(index, item) {
			rootMap[items[index].id] = true;
		});
		mui.each(items, function(index, item) {
			var treeItem = items[index];
			if (treeItem.parentId == 0) {
				rootMap[treeItem.id] = true;
			} else {
				if (rootMap.hasOwnProperty(treeItem.parentId)) {
					rootMap[treeItem.id] = false;
				}
			}
		});
		return rootMap;
	};

	own.bindDepartmentEvents = function(
		showAll,
		hasSpecial,
		nullMine,
		nullSub,
		isUser,
		isCuetomer,
		isFeeOwner,
		isFeeBiz,
		isFeeWc,
		departmentCellId,
		departmentNameShowId,
		departmentPageId,
		departmentParentBtnId,
		departmentParentTitleId,
		departmentsWrapperId,
		departmentConfirmBtnId,
		departmentChangeCallback,
		getCurrentDepartmentCallback
	) {
		var $departmentPage = mui('#' + departmentPageId);
		var objDepartmentsWrapper = document.getElementById(departmentsWrapperId);
		var objDepartmentParentBtn = document.getElementById(departmentParentBtnId);
		var objDepartmentParentTitle = document.getElementById(departmentParentTitleId);
		var objSelectedDepartmentName = document.getElementById(departmentNameShowId);

		var tmpDepartmentId = -1,
			tmpDepartmentName = '全部部门';

		var rootDepartmentMap = checkTreeRoots(departments);

		document.querySelector('#' + departmentCellId).addEventListener('tap', function() {
			var departmentId = getCurrentDepartmentCallback();
			if (!departmentId || departmentId <= 0) {
				departmentId = 0;
			}
			if (hasSpecial) {
				tmpDepartmentId = -2;
			} else {
				tmpDepartmentId = -1;
			}
			renderDepartments(showAll, hasSpecial, nullMine, nullSub, departments, 0, objDepartmentParentTitle,
				objDepartmentParentBtn, objDepartmentsWrapper, rootDepartmentMap);
		});

		//子部门筛选
		$departmentPage.on('tap', '.department-navigate-sub', function() {
			var dataId = this.getAttribute('data-id');

			renderDepartments(showAll, hasSpecial, nullMine, nullSub, departments, dataId, objDepartmentParentTitle,
				objDepartmentParentBtn, objDepartmentsWrapper, rootDepartmentMap);
		});

		//部门筛选返回
		objDepartmentParentBtn.addEventListener('tap', function() {
			renderParentDepartments(showAll, hasSpecial, nullMine, nullSub, departments, objDepartmentParentTitle,
				objDepartmentParentBtn, objDepartmentsWrapper, rootDepartmentMap);
			return false;
		});

		//只有一个部门
		if (departments.length == 1 && !showAll) {
			tmpDepartmentId = departments[0].id;
			tmpDepartmentName = departments[0].name;

			objSelectedDepartmentName.innerText = tmpDepartmentName;

			departmentChangeCallback && departmentChangeCallback(tmpDepartmentId, tmpDepartmentName);
		}

		//选中申请部门
		$departmentPage.on('change', 'input[name="departmentId"]', function() {
			tmpDepartmentId = this.value;
			tmpDepartmentName = this.getAttribute('data-name');

			if (isUser) {
				document.getElementById('selectedOwnerName').innerText = '';
				document.getElementById('selectedReceiveBankName').innerText = '';

				billOwner = -1;
				receiveBankId = -1;
				receiveBankName = '';
				receiveBankNum = '';
			}

			if (isCuetomer) {
				document.getElementById('selectedOwnerName').innerText = '';
				billOwner = -1;
			}

			if (isFeeOwner) {
				document.getElementById('feeSelectedOwnerName').innerText = '';
				currentFee.owner = -2;
				currentFee.ownerName = '';
			}

			if (isFeeBiz) {
				document.getElementById('feeSelectedBizName').innerText = '';
				currentFee.bizId = -2;
				currentFee.bizName = '';
			}

			if (isFeeWc) {
				document.getElementById('feeSelectedWcName').innerText = '';
				currentFee.wcId = -2;
				currentFee.wcName = '';
			}
		});

		//确认申请部门
		$departmentPage.on('tap', '#' + departmentConfirmBtnId, function() {
			if (showAll || hasSpecial) {
				if (tmpDepartmentId < -1) {
					mui.toast('请选择部门');
					return false;
				}
			} else {
				if (tmpDepartmentId < 0) {
					mui.toast('请选择部门');
					return false;
				}
			}
			objSelectedDepartmentName.innerText = tmpDepartmentName;

			objDepartmentsWrapper.innerHTML = '';

			departmentChangeCallback && departmentChangeCallback(tmpDepartmentId, tmpDepartmentName);
		});
	}

	own.initAllDepartmentBook = function(options, callback) {
		options = options || {};
		var departmentTapId = options.departmentTapId;
		var departmentShowId = options.departmentShowId;
		var title = options.title || '请选择部门';
		var showAll = options.showAll || false;
		var hasSpecial = options.hasSpecial || false;
		var splitByAccount = options.splitByAccount || false;
		var splitByOwn = options.splitByOwn || false;
		var accountId = options.accountId || -1;
		document.getElementById(departmentTapId).addEventListener('tap', function() {
			options.prepare && options.prepare();

			pushUserSelectWebView({
				source: 'DEPARTMENT',
				title: title,
				param: {
					url: MJ_URL.DEPT_API
				},
				showAll: showAll,
				hasSpecial: hasSpecial,
				splitByAccount: splitByAccount,
				accountId: accountId,
				splitByOwn: splitByOwn,
				callback: function(selected) {
					if (departmentShowId) document.getElementById(departmentShowId).innerText = selected.name;
					callback && callback(selected);
				}
			});
		});
	}

	own.initDepartmentBookSelectForPermission = function(options, callback) {
		options = options || {};
		var departmentTapId = options.departmentTapId;
		var departmentShowId = options.departmentShowId;
		var title = options.title || '请选择部门';
		var showAll = options.showAll || false;
		var hasSpecial = options.hasSpecial || false;
		var systemModule = options.systemModule || SYSTEM_MODULE_FIN;
		var t1 = options.t1 || '';
		var autoShow = options.autoShow || false;
		var showDepartments = options.showDepartments || [];
		document.getElementById(departmentTapId).addEventListener('tap', function() {
			options.prepare && options.prepare();

			pushUserSelectWebView({
				source: 'DEPARTMENT',
				title: title,
				param: {
					url: MJ_URL.DEPT_LIST_BY_PERMISSION,
					systemModule: systemModule,
					t1: t1,
				},
				showAll: showAll,
				hasSpecial: hasSpecial,
				autoshow: autoShow,
				showDepartments: showDepartments,
				callback: function(selected) {
					if (departmentShowId) document.getElementById(departmentShowId).innerText = selected.name;
					callback && callback(selected);
				}
			});
		});
	}

	own.initUserBookByDepartment = function(options, callback) {
		options = options || {};
		var userTapId = options.userTapId;
		var userShowId = options.userShowId;
		var showAll = options.showAll || false;
		var hasSpecial = options.hasSpecial || false;
		var showSubSelect = options.showSubSelect || false;
		var departmentId = options.department;
		document.getElementById(userTapId).addEventListener('tap', function() {
			options.prepare && options.prepare();

			var departmentId = options.checkDepartment();
			if (!departmentId) {
				return false;
			}

			pushUserSelectWebView({
				source: 'USER',
				title: '请选择员工',
				param: {
					url: MJ_URL.USER_LIST_BY_DEPT,
					department: departmentId
				},
				showAll: showAll,
				hasSpecial: hasSpecial,
				showSubSelect: showSubSelect,
				autoLoad: false,
				showUsers: [],
				callback: function(selected) {
					if (userShowId) document.getElementById(userShowId).innerText = selected.name;
					callback && callback(selected);
				}
			});
		});
	}

	own.initAllUserBook = function(options, callback) {
		options = options || {};
		var userTapId = options.userTapId;
		var userShowId = options.userShowId;
		var showAll = options.showAll || false;
		var hasSpecial = options.hasSpecial || false;
		var showSubSelect = options.showSubSelect || false;
		document.getElementById(userTapId).addEventListener('tap', function() {
			options.prepare && options.prepare();

			pushUserSelectWebView({
				source: 'USER',
				title: '请选择员工',
				param: {
					url: MJ_URL.USER_LIST_BY_ALL
				},
				showAll: showAll,
				hasSpecial: hasSpecial,
				showSubSelect: showSubSelect,
				autoLoad: false,
				showUsers: [],
				callback: function(selected) {
					if (userShowId) document.getElementById(userShowId).innerText = selected.name;
					callback && callback(selected);
				}
			});
		});
	}

	own.doInitUserBook = function(url, options, callback) {
		options = options || {};
		var systemModule = options.systemModule || SYSTEM_MODULE_FIN;
		var t1 = options.t1 || '';
		var userTapId = options.userTapId;
		var userShowId = options.userShowId;
		var showAll = options.showAll || false;
		var showOwn = options.showOwn || false;
		var hasSpecial = options.hasSpecial || false;
		var showSubSelect = options.showSubSelect || false;
		document.getElementById(userTapId).addEventListener('tap', function() {
			options.prepare && options.prepare();

			pushUserSelectWebView({
				source: 'USER',
				title: '请选择员工',
				param: {
					url: url,
					systemModule: systemModule,
					t1: t1
				},
				showOwn: showOwn,
				showAll: showAll,
				hasSpecial: hasSpecial,
				showSubSelect: showSubSelect,
				autoLoad: false,
				showUsers: [],
				callback: function(selected) {
					if (userShowId) document.getElementById(userShowId).innerText = selected.name;
					callback && callback(selected);
				}
			});
		});
	}

	own.initUserBookForPermission = function(options, callback) {
		own.doInitUserBook(MJ_URL.USER_LIST_BY_PERMISSION, options, callback);
	}

	own.doInitConsumerBook = function(url, options, callback) {
		var systemModule = options.systemModule || SYSTEM_MODULE_FIN;
		var t1 = options.t1 || '';
		var consumerTapId = options.consumerTapId;
		var consumerShowId = options.consumerShowId;
		var showAll = options.showAll || false;
		var hasSpecial = options.hasSpecial || false;
		var splitByAccount = options.splitByAccount || false;
		var accountId = options.accountId || -1;
		document.getElementById(consumerTapId).addEventListener('tap', function() {
			pushUserSelectWebView({
				source: 'CONSUMER',
				title: '请选择客户',
				param: {
					url: url,
					systemModule: systemModule,
					t1: t1
				},
				showAll: showAll,
				hasSpecial: hasSpecial,
				splitByAccount: splitByAccount,
				accountId: accountId,
				callback: function(selected) {
					if (consumerShowId) document.getElementById(consumerShowId).innerText = selected.name;
					callback && callback(selected);
				}
			});
		});
	}

	own.initConsumerBookForPermission = function(options, callback) {
		doInitConsumerBook(MJ_URL.CC_LIST_BY_PERMISSION, options, callback);
	}

	own.initWorkConsumerBookByPermissionForHr = function(options, callback) {
		options.systemModule = SYSTEM_MODULE_HR;
		options.t1 = 'work';
		initConsumerBookForPermission(options, callback);
	}

	own.initWorkConsumerBookByPermissionForFin = function(options, callback) {
		options.systemModule = SYSTEM_MODULE_FIN;
		options.t1 = 'work';
		initConsumerBookForPermission(options, callback);
	}

	own.initReportConsumerBookByPermissionForSale = function(options, callback) {
		options.systemModule = SYSTEM_MODULE_SALE;
		options.t1 = 'report';
		initConsumerBookForPermission(options, callback);
	}

	//分析图的客户
	own.initAllConsumerBookForReport = function(options, callback) {
		options = options || {};
		var consumerTapId = options.consumerTapId;
		var consumerShowId = options.consumerShowId;
		var hasSpecial = options.hasSpecial || false;
		document.getElementById(consumerTapId).addEventListener('tap', function() {
			pushUserSelectWebView({
				source: 'CONSUMER',
				title: '请选择客户',
				param: {
					url: MJ_URL.CC_LIST_ALL,
				},
				hasSpecial: hasSpecial,
				callback: function(selected) {
					if (consumerShowId) document.getElementById(consumerShowId).innerText = selected.name;
					callback && callback(selected);
				}
			});
		});
	}

	//利润分析表的客户
	own.initConsumerSelectForReport = function(
		opts,
		customerCellId,
		customerNameShowId,
		customerPageId,
		customersWrapperId,
		customerConfirmBtnId,
		customerChangeCallback,
		getCurrentCustomerCallback
	) {
		var hasSpecial = opts.hasSpecial;
		var $customerPage = mui('#' + customerPageId);
		var objCustomerByDepartmentWrapper = document.getElementById(customersWrapperId);
		var tmpFeeCustomerId = -1,
			tmpFeeCustomerName = '';
		document.querySelector('#' + customerCellId).addEventListener('tap', function() {
			mj.showLoading();
			objCustomerByDepartmentWrapper.innerHTML = '';

			if (hasSpecial) {
				tmpFeeCustomerId = -2;
				objCustomerByDepartmentWrapper.innerHTML += getNullCustomerItem();
			} else {
				tmpFeeCustomerId = -1;
			}
			mjQueryAllConsumers(function(data) {
				objCustomerByDepartmentWrapper.innerHTML += getCustomersListForReport(data);
				setTimeout(function() {
					mj.hideLoading();
				}, 300);
			});
		});

		$customerPage.on('change', 'input[name="customer"]', function() {
			tmpFeeCustomerId = this.value;
			tmpFeeCustomerName = this.getAttribute('data-name');
		});

		var objFeeSelectedCustomerName = document.getElementById(customerNameShowId);
		$customerPage.on('tap', '#' + customerConfirmBtnId, function() {
			objFeeSelectedCustomerName.innerText = tmpFeeCustomerName;
			objCustomerByDepartmentWrapper.innerHTML = '';
			customerChangeCallback && customerChangeCallback(tmpFeeCustomerId, tmpFeeCustomerName);
		});
	}

	own.bindProjectEvents = function(
		showAll,
		hasSpecial,
		projects,
		projectCellId,
		projectNameShowId,
		projectPageId,
		projectParentBtnId,
		projectParentTitleId,
		projectsWrapperId,
		projectConfirmBtnId,
		projectChangeCallback,
		getCurrentProjectCallback
	) {
		var $projectPage = mui('#' + projectPageId);
		var objProjectsWrapper = document.getElementById(projectsWrapperId);
		var objProjectParentBtn = document.getElementById(projectParentBtnId);
		var objProjectParentTitle = document.getElementById(projectParentTitleId);
		var objSelectedProjectName = document.getElementById(projectNameShowId);

		var tmpProjectId = -2,
			tmpProjectName = '全部项目';

		var rootProjectMap = checkTreeRoots(projects);

		document.querySelector('#' + projectCellId).addEventListener('tap', function() {
			var projectId = getCurrentProjectCallback();
			if (!projectId || projectId <= 0) {
				projectId = 0;
			}
			tmpProjectId = -2;

			renderProjects(showAll, hasSpecial, projects, 0, objProjectParentTitle, objProjectParentBtn, objProjectsWrapper,
				rootProjectMap);
		});

		//子项目筛选
		$projectPage.on('tap', '.project-navigate-sub', function() {
			var dataId = this.getAttribute('data-id');
			renderProjects(showAll, hasSpecial, projects, dataId, objProjectParentTitle, objProjectParentBtn,
				objProjectsWrapper, rootProjectMap);
		});

		//项目筛选返回
		objProjectParentBtn.addEventListener('tap', function() {
			renderParentProjects(showAll, hasSpecial, projects, objProjectParentTitle, objProjectParentBtn,
				objProjectsWrapper, rootProjectMap);
			return false;
		});
		//只有一个项目
		if (projects.length == 1 && !showAll) {
			tmpProjectId = projects[0].id;
			tmpProjectName = projects[0].name;

			objSelectedProjectName.innerText = tmpProjectName;

			projectChangeCallback && projectChangeCallback(tmpProjectId, tmpProjectName);
		}

		//选中项目
		$projectPage.on('change', 'input[name="projectId"]', function() {
			tmpProjectId = this.value;
			tmpProjectName = this.getAttribute('data-name');
		});

		//确认项目
		$projectPage.on('tap', '#' + projectConfirmBtnId, function() {
			if (hasSpecial) {
				if (tmpProjectId < -1) {
					mui.toast('请选择项目');
					return false;
				}
			} else if (showAll) {
				if (tmpProjectId < -1) {
					mui.toast('请选择项目');
					return false;
				}
			} else {
				if (tmpProjectId < 0) {
					mui.toast('请选择项目');
					return false;
				}
			}

			objSelectedProjectName.innerText = tmpProjectName;

			objProjectsWrapper.innerHTML = '';

			projectChangeCallback && projectChangeCallback(tmpProjectId, tmpProjectName);
		});
	}

	//项目通讯簿
	own.doInitProjectBook = function(options, callback) {
		options = options || {};
		var projectUrl = options.projectUrl;
		var projectTapId = options.projectTapId;
		var projectShowId = options.projectShowId;
		var systemModule = options.systemModule || SYSTEM_MODULE_FIN;
		var projectType = options.projectType || PROJECT_TYPE_ALL;
		var anaType = options.anaType || '';
		var title = options.title || '请选择项目';
		var showAll = options.showAll || false;
		var hasSpecial = options.hasSpecial || false;
		var splitByAccount = options.splitByAccount || false;
		var accountId = options.accountId || -1;
		var autoShow = options.autoShow || false;
		var showProjects = options.showProjects || [];
		document.getElementById(projectTapId).addEventListener('tap', function() {
			options.prepare && options.prepare();

			pushUserSelectWebView({
				source: 'PROJECT',
				title: title,
				param: {
					url: projectUrl,
					systemModule: systemModule,
					projectType: projectType,
					anaType: anaType
				},
				showAll: showAll,
				hasSpecial: hasSpecial,
				splitByAccount: splitByAccount,
				accountId: accountId,
				autoshow: autoShow,
				showProjects: showProjects,
				callback: function(selected) {
					if (projectShowId) document.getElementById(projectShowId).innerText = selected.name;
					callback && callback(selected);
				}
			});
		});
	}

	own.initAllProjectBook = function(options, callback) {
		options = options || {};
		options.projectUrl = MJ_URL.PROJ_LIST_ALL;
		doInitProjectBook(options, callback);
	}

	own.initProjectBookForJoined = function(options, callback) {
		options = options || {};
		options.projectUrl = MJ_URL.PROJ_LIST_JOINED;
		doInitProjectBook(options, callback);
	}

	own.initProjectBookForPermission = function(options, callback) {
		options = options || {};
		options.projectUrl = MJ_URL.PROJ_LIST_PERMISSION;
		doInitProjectBook(options, callback);
	}

	own.initWorkProjectBookByPermissionForFin = function(options, callback) {
		options.systemModule = SYSTEM_MODULE_FIN;
		options.projectType = PROJECT_TYPE_ALL;
		options.anaType = 'work';
		initProjectBookForPermission(options, callback);
	}

	own.initWorkProjectBookByPermissionForHr = function(options, callback) {
		options.systemModule = SYSTEM_MODULE_HR;
		options.projectType = PROJECT_TYPE_ALL;
		options.anaType = 'work';
		initProjectBookForPermission(options, callback);
	}

	own.initManageProjectBookByPermissionForHr = function(options, callback) {
		options.systemModule = SYSTEM_MODULE_HR;
		options.projectType = PROJECT_TYPE_ALL;
		options.anaType = 'manage';
		initProjectBookForPermission(options, callback);
	}

	own.initAccountBook = function(options, callback) {
		options = options || {};
		var accountTapId = options.accountTapId;
		var accountShowId = options.accountShowId;
		var title = options.title || '请选择帐套';
		var showAll = options.showAll || false;
		var isShare = options.isShare || false;
		var prepareData = options.prepareData || false;
		var showAccounts = options.showAccounts || [];

		document.getElementById(accountTapId).addEventListener('tap', function() {
			options.prepare && options.prepare();
			var showRelatedAccount = options.showRelatedAccount && options.showRelatedAccount();

			pushUserSelectWebView({
				source: 'ACCOUNT',
				title: title,
				param: {
					url: MJ_URL.AB_LIST_ALL
				},
				showAll: showAll,
				isShare: isShare,
				showRelatedAccount: showRelatedAccount,
				prepareData: prepareData,
				showAccounts: showAccounts,
				callback: function(selected) {
					if (accountShowId) document.getElementById(accountShowId).innerText = selected.name;
					callback && callback(selected);
				}
			});
		});
	}

	//部门筛选(向下级筛选)
	own.renderDepartments = function(showAll, hasSpecial, nullMine, nullSub, departments, parentId, $parentTitle,
		$backParentBtn, $container, rootDepartmentMap) {
		var curDepartments = [];
		var departmentlistHtml = '';

		var parentName = '',
			parentPath = '';

		mj.showLoading();

		if (parentId == 0) {
			$backParentBtn.classList.add('mui-action-back');
			if (showAll) {
				departmentlistHtml += getAllDepartmentItem();
			}
			if (hasSpecial) {
				departmentlistHtml += getNullDepartmentItem();
			}
			if (!nullMine) {
				departmentlistHtml += getMineDepartmentList(mj.getDepartments());
			}
		} else {
			$backParentBtn.classList.remove('mui-action-back');
		}

		if (!nullSub) {
			if (parentId == 0) {
				parentName = '请选择部门';
				parentPath = '0';
				mui.each(departments, function(index, item) {
					var department = departments[index];
					if (rootDepartmentMap[department.id]) {
						curDepartments.push(department);
					}
				});
			} else {
				mui.each(departments, function(index, item) {
					var department = departments[index];
					if (department.id == parentId) {
						parentName = department.name;
						parentPath = department.path;
					}
					if (department.parentId == parentId) {
						curDepartments.push(department);
					}
				});
			}

			departmentlistHtml += getDepartmentList(curDepartments);

			$backParentBtn.setAttribute('data-path', parentPath);
			$parentTitle.innerText = parentName;
		}

		$container.innerHTML = departmentlistHtml;
		setTimeout(function() {
			mj.hideLoading();
		}, 300);
	}

	//部门筛选（返回父部门筛选）
	own.renderParentDepartments = function(showAll, hasSpecial, nullMine, nullSub, departments, $parentTitle,
		$backParentBtn, $container, rootDepartmentMap) {
		var dataPath = $backParentBtn.getAttribute('data-path');
		var dataPathArray = dataPath.split('-');
		var parentId = dataPathArray.pop();
		renderDepartments(showAll, hasSpecial, nullMine, nullSub, departments, parentId, $parentTitle, $backParentBtn,
			$container, rootDepartmentMap);
	}

	//项目筛选（向下级筛选）
	own.renderProjects = function(showAll, hasSpecial, projects, parentId, $parentTitle, $backParentBtn, $container,
		rootProjectMap) {
		var curProjects = [];
		var projectlistHtml = '';

		var parentName = '',
			parentPath = '';

		mj.showLoading();

		if (parentId == 0) {
			$backParentBtn.classList.add('mui-action-back');
			if (hasSpecial) {
				projectlistHtml += getNullProjectItem();
			}
			if (showAll) {
				projectlistHtml += getAllProjectItem();
			}
			//			projectlistHtml += getMineProjectList(mj.getProjects());
		} else {
			$backParentBtn.classList.remove('mui-action-back');
		}

		if (parentId == 0) {
			parentName = '请选择项目';
			parentPath = '0';
			mui.each(projects, function(index, item) {
				var project = projects[index];
				if (rootProjectMap[project.id]) {
					curProjects.push(project);
				}
			});
		} else {
			mui.each(projects, function(index, item) {
				var project = projects[index];
				if (project.id == parentId) {
					parentName = project.name;
					parentPath = project.path;
				}
				if (project.parentId == parentId) {
					curProjects.push(project);
				}
			});
		}

		projectlistHtml += getProjectsList(curProjects);

		$backParentBtn.setAttribute('data-path', parentPath);
		$parentTitle.innerText = parentName;

		$container.innerHTML = projectlistHtml;
		setTimeout(function() {
			mj.hideLoading();
		}, 300);
	}

	//项目筛选（返回父项目筛选）
	own.renderParentProjects = function(showAll, hasSpecial, projects, $parentTitle, $backParentBtn, $container,
		rootProjectMap) {
		var dataPath = $backParentBtn.getAttribute('data-path');
		var dataPathArray = dataPath.split('-');
		var parentId = dataPathArray.pop();
		renderProjects(showAll, hasSpecial, projects, parentId, $parentTitle, $backParentBtn, $container, rootProjectMap);
	}

	//我的部门列表
	own.getMineDepartmentList = function(list) {
		var listHtml =
			'<div class="mui-input-group mj-radio-group">' +
			'	<div class="table-view-cell-title"><div class="page-list-title department-list-title">我的部门</div></div>';
		var listItem;
		for (var i = 0; i < list.length; i++) {
			listItem = list[i];
			listHtml +=
				'	<div class="mui-input-row mui-radio mui-left">' +
				'		<label>' + list[i].name + '</label>' +
				'		<input name="departmentId" type="radio" value="' + list[i].id + '" data-name="' + list[i].name + '">' +
				'	</div>';
		}
		listHtml += '</div>'
		return listHtml;
	}

	//所有部门列表
	own.getDepartmentList = function(list) {
		if (list.length == 0) {
			return '';
		}
		var listHtml = '<div class="mui-input-group mj-radio-group">' +
			'<div class="table-view-cell-title"><div class="page-list-title department-list-title">所有部门</div></div>';
		var listItem;
		for (var i = 0; i < list.length; i++) {
			listItem = list[i];
			listHtml += '<div class="mui-input-row">' +
				'	<div class="mui-radio mui-left level-list-radio department-list-radio">' +
				'		<label>' + list[i].name + '</label>' +
				'		<input name="departmentId" type="radio" value="' + list[i].id + '" data-name="' + list[i].name + '">' +
				'	</div>' +
				'	<a href="javascript;" class="department-navigate-sub page-navigate-sub" data-id="' + list[i].id +
				'" data-path="' + list[i].path + '" data-name="' + list[i].name + '" data-pid="' + list[i].parentId +
				'"><span class="mui-icon">&gt;</span></a>' +
				'</div>'
		}
		listHtml += '</div>';
		return listHtml;
	}

	//部门列表的全部选项
	own.getAllDepartmentItem = function() {
		var listHtml =
			'<div class="mui-input-group mj-radio-group">' +
			'	<div class="mui-input-row mui-radio mui-left">' +
			'		<label>全部</label>' +
			'		<input name="departmentId" type="radio" value="-1" data-name="全部部门">' +
			'	</div>' +
			'</div>';
		return listHtml;
	}

	own.getBookBoxFirst = function() {
		return '<div id="mjBookList" class="mui-indexed-list">\
				<div class="mui-indexed-list-search mui-input-row mui-search">\
					<input type="search" class="mui-input-clear mui-indexed-list-search-input indexed-list-search-input" placeholder="搜索">\
				</div>\
				<div class="mui-indexed-list-bar">\
					<a>#</a>\
					<a>A</a>\
					<a>B</a>\
					<a>C</a>\
					<a>D</a>\
					<a>E</a>\
					<a>F</a>\
					<a>G</a>\
					<a>H</a>\
					<a>I</a>\
					<a>J</a>\
					<a>K</a>\
					<a>L</a>\
					<a>M</a>\
					<a>N</a>\
					<a>O</a>\
					<a>P</a>\
					<a>Q</a>\
					<a>R</a>\
					<a>S</a>\
					<a>T</a>\
					<a>U</a>\
					<a>V</a>\
					<a>W</a>\
					<a>X</a>\
					<a>Y</a>\
					<a>Z</a>\
				</div>\
				<div class="mui-indexed-list-alert"></div>\
				<div class="mui-indexed-list-inner">\
					<div class="mui-indexed-list-empty-alert">没有数据</div>\
					<ul class="mui-table-view" id="mjBookListWrapper">';
	}

	own.getBookBoxEnd = function() {
		return '</ul>\
				</div>\
			</div>';
	}

	own.getBookKeyItem = function(itemKey, customItemKey) {
		return '<li data-group="' + itemKey + '" class="mui-table-view-divider mui-indexed-list-group">' + (customItemKey ?
			customItemKey : itemKey) + '</li>';
	}

	own.getBookRadioItem = function(id, name) {
		return '<li class="mui-table-view-cell mui-indexed-list-item mui-radio mui-left"><input name="mjBookItem" type="radio" value="' +
			id + '" data-name="' + name + '" />' + name + '</li>';
	}

	own.getNeedSpecialFieldBookRadioItem = function(id, name, field) {
		return '<li class="mui-table-view-cell mui-indexed-list-item mui-radio mui-left"><input name="mjBookItem" type="radio" value="' +
			id + '" data-name="' + name + '" data-type="' + field + '" />' + name + '</li>';
	}

	own.getBankBookRadioItem = function(id, name, showName, bankNum, bankCode) {
		return '<li class="mui-table-view-cell mui-indexed-list-item mui-radio mui-left"><input name="mjBookItem" type="radio" value="' +
			id + '" data-name="' + name + '" data-banknum="' + bankNum + '" data-bankcode="' + bankCode + '" />' + showName +
			'</li>';
	}

	own.getBookCheckboxItem = function(id, name) {
		return '<li class="mui-table-view-cell mui-indexed-list-item mui-checkbox mui-left"><input name="mjBookItem" type="checkbox" value="' +
			id + '" data-name="' + name + '" />' + name + '</li>';
	}

	//无归属人
	own.getNullOwnerItem = function() {
		var listHtml =
			'<div class="mui-input-group mj-radio-group">' +
			'     <div class="mui-input-row mui-radio mui-left">' +
			'       <label>无</label>' +
			'       <input name="owner" type="radio" value="-1" data-name="无">' +
			'     </div>' +
			'</div>';
		return listHtml;
	}

	//无部门
	own.getNullDepartmentItem = function() {
		var listHtml =
			'<div class="department-wrapper">' +
			'	<ul class="mui-table-view mui-table-view-chevron mj-radio-table-view modal-select-list">' +
			'		<li class="mui-table-view-cell">' +
			'			<div class="mui-input-row mui-radio mui-left">' +
			'				<label>无</label>' +
			'				<input name="departmentId" type="radio" value="-1" data-name="无">' +
			'			</div>' +
			'		</li>' +
			'	</ul>' +
			'</div>';
		return listHtml;
	}

	//无项目
	own.getNullProjectItem = function() {
		var listHtml =
			'<div class="project-wrapper">' +
			'	<ul class="mui-table-view mui-table-view-chevron mj-radio-table-view modal-select-list">' +
			'		<li class="mui-table-view-cell">' +
			'			<div class="mui-input-row mui-radio mui-left">' +
			'				<label>无</label>' +
			'				<input name="projectId" type="radio" value="-1" data-name="无">' +
			'			</div>' +
			'		</li>' +
			'	</ul>' +
			'</div>';
		return listHtml;
	}

	//无业务员
	own.getNullUserItem = function() {
		var listHtml =
			'<div class="owner-wrapper">' +
			'	<ul class="mui-table-view mui-table-view-chevron mj-radio-table-view modal-select-list">' +
			'		<li class="mui-table-view-cell">' +
			'			<div class="mui-input-row mui-radio mui-left">' +
			'				<label>无</label>' +
			'				<input name="owner" type="radio" value="-1" data-name="无">' +
			'			</div>' +
			'		</li>' +
			'	</ul>' +
			'</div>';
		return listHtml;
	}

	//无往来单位
	own.getNullCustomerItem = function() {
		var listHtml =
			'<div class="biz-wrapper">' +
			'	<ul class="mui-table-view mui-table-view-chevron mj-radio-table-view modal-select-list">' +
			'		<li class="mui-table-view-cell">' +
			'			<div class="mui-input-row mui-radio mui-left">' +
			'				<label>无</label>' +
			'				<input name="customer" type="radio" value="-1" data-name="无">' +
			'			</div>' +
			'		</li>' +
			'	</ul>' +
			'</div>';
		return listHtml;
	}

	//无车辆
	own.getNullCarItem = function() {
		var listHtml =
			'<div class="car-wrapper">' +
			'	<ul class="mui-table-view mui-table-view-chevron mj-radio-table-view modal-select-list">' +
			'		<li class="mui-table-view-cell">' +
			'			<div class="mui-input-row mui-radio mui-left">' +
			'				<label>无</label>' +
			'				<input name="carId" type="radio" value="-1" data-name="无">' +
			'			</div>' +
			'		</li>' +
			'	</ul>' +
			'</div>';
		return listHtml;
	}

	//我的项目列表
	own.getMineProjectList = function(list) {
		var listHtml =
			'<div class="mui-input-group mj-radio-group">' +
			'	<div class="table-view-cell-title"><div class="page-list-title department-list-title">我的项目</div></div>';
		var listItem;
		for (var i = 0; i < list.length; i++) {
			listItem = list[i];
			listHtml +=
				'	<div class="mui-input-row mui-radio mui-left">' +
				'		<label>' + list[i].name + '</label>' +
				'		<input name="projectId" type="radio" value="' + list[i].id + '" data-name="' + list[i].name.replace(/\"/g, "") +
				'">' +
				'	</div>';
		}
		listHtml += '</div>';
		return listHtml;
	}
	//项目列表
	own.getProjectsList = function(list) {
		if (list.length == 0) {
			return '';
		}
		var listHtml = '<div class="mui-input-group mj-radio-group">';
		var listItem;
		for (var i = 0; i < list.length; i++) {
			listItem = list[i];
			listHtml += '<div class="mui-input-row">' +
				'	<div class="mui-radio mui-left level-list-radio project-list-radio">' +
				'		<label>' + list[i].name + '</label>' +
				'		<input name="projectId" type="radio" value="' + list[i].id + '" data-name="' + list[i].name.replace(/\"/g, "") +
				'">' +
				'	</div>' +
				'	<a href="javascript;" class="project-navigate-sub page-navigate-sub" data-id="' + list[i].id + '" data-path="' +
				list[i].path + '" data-name="' + list[i].name + '" data-pid="' + list[i].parentId +
				'"><span class="mui-icon">&gt;</span></a>' +
				'</div>'
		}
		listHtml += '</div>';
		return listHtml;
	}

	//项目列表的全部选项
	own.getAllProjectItem = function() {
		var listHtml =
			'<div class="mui-input-group mj-radio-group">' +
			'	<div class="mui-input-row mui-radio mui-left">' +
			'		<label>全部</label>' +
			'		<input name="projectId" type="radio" value="-1" data-name="全部项目">' +
			'	</div>' +
			'</div>';
		return listHtml;
	}

	//员工列表
	own.getUsersList = function(list) {
		var listHtml = '<div class="mui-input-group mj-radio-group">';
		var listItem;
		for (var i = 0; i < list.length; i++) {
			listItem = list[i];
			listHtml +=
				'	<div class="mui-input-row mui-radio mui-left">' +
				'		<label>' + list[i].nickName + '</label>' +
				'		<input name="owner" type="radio" value="' + list[i].id + '" data-name="' + list[i].nickName + '">' +
				'	</div>';
		}
		listHtml += '</div>'
		return listHtml;
	}

	//人员列表的全部选项
	own.getAllOwnerItem = function() {
		var listHtml =
			'<div class="mui-input-group mj-radio-group">' +
			'	<div class="mui-input-row mui-radio mui-left">' +
			'		<label>全部</label>' +
			'		<input name="owner" type="radio" value="-1" data-name="全部人员">' +
			'	</div>' +
			'</div>';
		return listHtml;
	}

	//所有下属和所有直接下属
	function getSubSelectOwnerList() {
		var listHtml = '' +
			'<div class="mui-input-group mj-radio-group">' +
			'	<div class="mui-input-row mui-radio mui-left">' +
			'		<label>所有直接下级</label>' +
			'		<input name="owner" type="radio" value="-100" data-name="所有直接下级">' +
			'	</div>' +
			'	<div class="mui-input-row mui-radio mui-left">' +
			'		<label>所有下级</label>' +
			'		<input name="owner" type="radio" value="-200" data-name="所有下级">' +
			'	</div>' +
			'</div>';
		return listHtml;
	}

	//分析人员列表
	own.getReportUserList = function(list) {
		var listHtml = '<div class="mui-input-group mj-radio-group">' +
			'	<div class="mui-input-row mui-radio mui-left">' +
			'		<label>本人</label>' +
			'		<input name="owner" type="radio" value="' + mj.getId() + '" data-name="本人">' +
			'	</div>';
		var listItem;
		for (var i = 0; i < list.length; i++) {
			listItem = list[i];
			listHtml += '	<div class="mui-input-row mui-radio mui-left">' +
				'		<label>' + list[i].nickName + '</label>' +
				'		<input name="owner" type="radio" value="' + list[i].id + '" data-name="' + list[i].nickName + '">' +
				'	</div>';
		}
		listHtml += '</div>';
		return listHtml;
	}

	//往来单位列表
	own.getCustomersListForReport = function(list) {
		var listHtml = '<div class="mui-input-group mj-radio-group">';
		var listItem;
		for (var i = 0; i < list.length; i++) {
			listItem = list[i];
			listHtml += '	<div class="mui-input-row mui-radio mui-left">' +
				'		<label>' + list[i].name + '</label>' +
				'		<input name="customer" type="radio" value="' + list[i].id + '" data-name="' + list[i].name + '">' +
				'	</div>';
		}
		listHtml += '</div>';
		return listHtml;
	}

	//车辆列表
	own.getCarsList = function(list) {
		var listHtml = '<div class="mui-input-group mj-radio-group">';
		var listItem;
		for (var i = 0; i < list.length; i++) {
			listItem = list[i];
			listHtml +=
				'	<div class="mui-input-row mui-radio mui-left">' +
				'		<label>' + list[i].carNum + '</label>' +
				'		<input name="carId" type="radio" value="' + list[i].id + '" data-name="' + list[i].carNum + '">' +
				'	</div>';
		}
		listHtml += '</div>'
		return listHtml;
	}


	//弹出键盘时隐藏底部按钮
	own.hideBottomButtom = function($btn) {
		window.addEventListener('resize', function() {
			$btn.style.display = document.body.clientHeight <= 400 ? 'none' : 'block';
		}, false);
	}

	own.badgeKey = 'badge_total_number';
	own.BadgeManager = function() {};
	own.BadgeManager.setInc = function(num) {
		var total_number = plus.storage.getItem(own.badgeKey);
		total_number = parseInt(total_number);
		if (!total_number) total_number = 0;
		total_number = total_number + num;
		plus.storage.setItem(own.badgeKey, total_number.toString());
		plus.runtime.setBadgeNumber(total_number);
	};
	own.BadgeManager.setBadgeNumber = function(num) {
		plus.storage.setItem(own.badgeKey, num.toString());
		plus.runtime.setBadgeNumber(num);
	};
	own.BadgeManager.getBadgeNumber = function() {
		var total_number = plus.storage.getItem(own.badgeKey);
		total_number = parseInt(total_number);
		if (!total_number) total_number = 0;
		return total_number;
	};
	own.BadgeManager.reset = function() {
		if (mui.os.ios) {
			var geTuiSdk = plus.ios.importClass('GeTuiSdk');
			geTuiSdk.resetBadge();
			plus.runtime.setBadgeNumber(0);
		}
		if (mui.os.android) {
			var pushManager = plus.android.importClass("com.igexin.sdk.PushManager");
			var context = plus.android.runtimeMainActivity();
			pushManager.getInstance().initialize(context);
		}
	};
	own.checkDataCache = function(data, showCallback, queryCallback) {
		if (!data) {
			queryCallback(function(datas) {
				showCallback(datas);
			});
		} else {
			showCallback(data);
		}
	};
})(window);
