;+function($){
    var $window = $(window);

    var Pager = function(element, options){
        this._process_options(options);

        this.element = $(element);
        this.pager = null;
        this.pageItems = [];

        this.show();
    };

    Pager.prototype = {
        constructor: Pager,

        _process_options: function(opts){
            this._o = $.extend({}, this._o, opts);
            var o = this.o = $.extend({}, this._o);

            o.handler = o.handler || this.handler;

            this.resetOptions();
        },
        say: function() {
        		mui.toast('hi');
        },

        handler: function(clickedPage,pageUrl){
			return true;
        },

        resultHandler: function(clickedPage){
            clickedPage = parseInt(clickedPage);

            var pageUrl = this.buildPageUrl(clickedPage);
            var isHandlerSucceed = this.o.handler(clickedPage,pageUrl);
            if(isHandlerSucceed){
                this.o.currentPage = clickedPage;

                this.resetOptions();
                this.resetData();
                this.show();
            }
        },

        resetOptions: function(){
            this.o.hasPrevious = this.o.currentPage > 1;
            this.o.hasNext = this.o.currentPage < this.o.totalPages;
        },

        resetData: function(){
            this.element.empty();
            this.pager = null;
            this.pageItems = [];
        },

        show: function(){
            this.render();
	        this.element.empty();
            this.pager.appendTo(this.element);
            this.bindListeners();
        },

        render: function(){
            var pagerHtml = this.renderPrevious();
            pagerHtml += this.renderItems();
            pagerHtml += this.renderNext();

            pagerHtml = $.fn.pagination.DPGlobal.template.replace('{{page:content}}', pagerHtml);
            pagerHtml = pagerHtml.replace('{{page:totalPages}}', this.o.totalPages);
            pagerHtml = pagerHtml.replace('{{page:totalNumber}}', this.o.totalNumber);
            pagerHtml = pagerHtml.replace('{{page:showTotalNumber}}',
                            !isNaN(this.o.totalNumber) && this.o.totalNumber>=0 ? '' : 'none'
                        );
            this.pager = $(pagerHtml);
        },

        buildPageUrl: function(pageIndex){
            return this.o.url.replace(/{{page:pageIndex}}/gm, pageIndex);
        },

        bindListeners: function(){
            var pager = this;
            
            mui('.mui-pagination').on('tap', 'a', function(){
            		var classList = this.classList;
            		if (classList.contains('prev')) {
            			if(pager.o.hasPrevious){
            				pager.resultHandler(parseInt(pager.o.currentPage) - 1);
            			} else {
            				mui.toast('已经是第一页');
            			}
            		}
            		
            		if (classList.contains('next')) {
            			if(pager.o.hasNext){
            				pager.resultHandler(parseInt(pager.o.currentPage) + 1);
            			} else {
            				mui.toast('已经是最后一页');
            			}
            		}
            		
            		if (classList.contains('page')) {
            			var itemPage = $(this).text();
            			if(pager.o.currentPage!=Number(itemPage)){
            				pager.resultHandler($(this).text());
            			}
            		}
            });
        },

        renderPrevious: function(){
            return this.buildPrevious();
        },

        buildPrevious: function(){
            var html = this.o.hasPrevious ? $.fn.pagination.DPGlobal.previousTemplate : $.fn.pagination.DPGlobal.noPreviousTemplate;
            return html;
        },

        renderNext: function(){
            return this.buildNext();
        },

        buildNext: function(){
            var html = this.o.hasNext ? $.fn.pagination.DPGlobal.nextTemplate : $.fn.pagination.DPGlobal.noNextTemplate;
            return html;
        },

        renderItems: function(){
            this.getItems();
            return this.showItems();
        },

        buildPage: function(pageIndex) {
            if(pageIndex == -1){
                return this.buildBlankPage();
            } else if(pageIndex == this.o.currentPage){
                return this.buildCurrentPage();
            } else {
                return this.buildItemPage(pageIndex);
            }
        },

        buildBlankPage: function(){
            return $.fn.pagination.DPGlobal.blankTemplate;
        },

        buildCurrentPage: function(){
            return $.fn.pagination.DPGlobal.currentTemplate.replace(/{{page:currentPage}}/gm, this.o.currentPage);
        },

        buildItemPage: function(pageIndex){
            return $.fn.pagination.DPGlobal.itemTemplate.replace(/{{page:itemIndex}}/gm, pageIndex);
        },

        showItems: function(){
            var pager = this;
            var html = '';
            $.each(this.pageItems,function(n,value){
                html += pager.buildPage(value);
            });
            return html;
        },

        getItems: function(){
            var curPage = this.o.currentPage;
            var totalPages = this.o.totalPages;
            var showRadius = $.fn.pagination.defaults.showRadius;
            var hasHead = false;
            var hasEnd = false;
            var pageStart, pageEnd;
            var pageItemList =  this.pageItems;

            //范围框在最小边界处震荡
            pageStart = curPage - showRadius;
            if (pageStart <= 0) {
                pageStart = 1;
                pageEnd = 1 + 2 * showRadius;
            } else {
                pageEnd = pageStart + 2 * showRadius;
            }

            //范围框在最大边界处震荡
            if (pageEnd > totalPages) {
                pageStart = totalPages - 2 * showRadius;
                pageEnd = totalPages;

                //范围框在最小边界回馈震荡
                if (pageStart <= 0) {
                    pageStart = 1;
                }
            }

            //范围框的最小边界处理
            if (pageStart <= 3) {
                pageStart = 1;
            } else {
                //添加在最小边界处的附加范围
                pageItemList.push(1);
                pageItemList.push(2);
                pageItemList.push(-1);
            }

            //范围框的最大边界处理
            if (totalPages - pageEnd <= 1) {
                pageEnd = totalPages;
            } else {
                hasEnd = true;
            }

            //取正常范围框
            for (var i = pageStart; i <= pageEnd; i++) {
                pageItemList.push(i);
            }

            //添加在最大边界处的附加范围
            if (hasEnd) {
                pageItemList.push(-1);
            }
        }
    }

    var old = $.fn.pagination;

    $.fn.pagination = function(option){
        option = option || {};
        var options = $.extend({}, $.fn.pagination.defaults, option);
        var host = this;

        var data = new Pager(this, options);

        return this;
    };

    $.fn.pagination.Constructor = Pager;

    var defaults = $.fn.pagination.defaults = {
        currentPage:1,
        totalPages:1,
        totalNumber:-1,
        url:'page={{page:pageIndex}}',
        showRadius:2,
        handler: undefined
    };

    var DPGlobal = $.fn.pagination.DPGlobal = {
        previousTemplate :  '<li class="mui-previous">' +
                                '<a class="prev" href="#">&laquo;</a>' +
                             '</li>',
        noPreviousTemplate : '<li class="mui-previous mui-disabled">' +
                                '<a href="#">&laquo;</a>' +
                             '</li>',
        nextTemplate:       '<li class="mui-next">' +
                                '<a class="next" href="#">&raquo;</a>' +
                             '</li>',
        noNextTemplate:     '<li class="mui-next mui-disabled">' +
                                '<a href="#">&raquo;</a>' +
                             '</li>',
        itemTemplate:       '<li>' +
                                '<a class="page" href="#">' +
                                    '{{page:itemIndex}}' +
                                '</a>' +
                            '</li>',
        currentTemplate:    '<li class="mui-active">' +
                                '<a href="#">' +
                                    '{{page:currentPage}}' +
                                '</a>' +
                            '</li>',
        blankTemplate:       '<li>' +
                                '<a href="#">' +
                                    '...' +
                                '</a>' +
                            '</li>'
    };

    DPGlobal.template = '<nav style="text-align:center">' +
                            '<ul class="mui-pagination">' +
                                '{{page:content}}' +
                            '</ul>' +
                        '</nav>';


    $.fn.pagination.noConflict = function(){
        $.fn.pagination = old;
        return this;
    };

}(window.jQuery);