var planType = { 1: '日计划', 2: '周计划', 3: '月计划', 4: '季计划', 5: '年计划', 6: '自定义计划' };

function getExpireInfo(task) {
	 var expireClass = '';
    if (task.status == TASK_STATUS_TASK) {
        var curTime = (new Date()).fixTimezone();
        expireClass = task.endTime< curTime ? ' expired' : undefined;
        expireClass = expireClass || (task.endTime<curTime.next(1)?'expiring':'');
    }
    return expireClass;
}

function generateEditBtn() {
	return '<a class="mui-btn mui-btn-royal edit-btn">编辑</a>';
}

function generateUploadBtn() {
	return '<a class="mui-btn mui-btn-primary upload-btn">上报</a>';
}

function generateDeleteBtn() {
	return '<a class="mui-btn mui-btn-danger delete-btn">删除</a>';
}

function generateCancelBtn() {
	return '<a class="mui-btn mui-btn-warning cancel-btn">取消上报</a>';
}

function generateProgressBtn() {
	return '<a class="mui-btn mui-btn-success progress-btn">报进度</a>';
}

function generateSplitBtn() {
	return '<a class="mui-btn mui-btn-grey split-btn">分解</a>';
}

function generateApproveBtn() {
	return '<a class="mui-btn mui-btn-success approve-btn">通过</a>';
}

function generateRejectBtn() {
	return '<a class="mui-btn mui-btn-danger reject-btn">拒绝</a>';
}

function generateCompleteBtn() {
	return '<a class="mui-btn mui-btn-warning complete-btn">完成</a>';
}

function generateScoreBtn() {
	return '<a class="mui-btn mui-btn-red score-btn">打分</a>';
}

function generateNullBtn() {
	return '<a class="mui-btn mui-disabled mui-btn-grey">无操作</a>';
}

function generateMineActionButtons(taskStatus) {
	var actionHtml = '';
	switch(taskStatus) {
		case TASK_STATUS_CREATED:
			actionHtml += generateEditBtn();
			actionHtml += generateUploadBtn();
			actionHtml += generateDeleteBtn();
			break;
		case TASK_STATUS_PLAN:
			actionHtml += generateCancelBtn();
			break;
		case TASK_STATUS_REJECTED:
			actionHtml += generateEditBtn();
			actionHtml += generateUploadBtn();
			actionHtml += generateDeleteBtn();
			break;
		case TASK_STATUS_TASK:
			actionHtml += generateProgressBtn();
//			actionHtml += generateSplitBtn();
			break;
		case TASK_STATUS_COMPLETED:
		case TASK_STATUS_SCORED:
		default:
			actionHtml = generateNullBtn();
			break;
	}
	return actionHtml;
}

function generateSubActionButtons(taskStatus, taskProgress) {
	var actionHtml = '';
	switch(taskStatus) {
		case TASK_STATUS_PLAN:
			actionHtml += generateApproveBtn();
			actionHtml += generateRejectBtn();
			break;
		case TASK_STATUS_TASK:
			if(taskProgress==0) {
				actionHtml += generateEditBtn();
				actionHtml += generateCompleteBtn();
				actionHtml += generateDeleteBtn();
			} else {
				actionHtml += generateCompleteBtn();
			}
			break;
		case TASK_STATUS_COMPLETED:
			actionHtml += generateScoreBtn();
			break;
		default:
			actionHtml = generateNullBtn();
			break;
	}
	return actionHtml;
}

function doUploadTask(taskId, objLi) {
	mj.showLoading();
	mj.post(MJ_URL.TASK_A_UP.mjFormat(taskId),{},
		function(){
			mj.alert('任务上报成功');
		},
		function(xhr){
			showResult(xhr, LOST_NETWORK_CONNECTION);
		},
		function(){
			mj.hideLoading();
		});
}

function doCancelTask(taskId, objLi) {
	mj.showLoading();
	mj.post(MJ_URL.TASK_A_CANCEL.mjFormat(taskId), {}, 
		function(){
			if (objLi) {
				var actionHtml = generateMineActionButtons(TASK_STATUS_CREATED);
				objLi.querySelector('.mui-slider-right').innerHTML = actionHtml;
				mui.swipeoutClose(objLi, 'right');
			}
			mj.alert('任务已取消上报');
		},
		function(xhr){
			showResult(xhr, LOST_NETWORK_CONNECTION);
		},
		function(){
			mj.hideLoading();
		});
}

function doDeleteTask(taskId, objLi) {
	mj.showLoading();
	mj.post(MJ_URL.TASK_A_DELETE.mjFormat(taskId), {}, 
		function(){
			if (objLi) {
				mj.alert('删除任务成功');
			}
		},
		function(xhr){
			showResult(xhr, LOST_NETWORK_CONNECTION);
		},
		function(){
			mj.hideLoading();
		});
}

function doApproveTask(taskId, callback) {
	mj.showLoading();
	mj.post(MJ_URL.TASK_A_APPROVE.mjFormat(taskId), {}, 
		function(){
			mj.alert('任务已审核通过', function() {
				callback && callback();
			});
		},
		function(xhr){
			showResult(xhr, LOST_NETWORK_CONNECTION);
		},
		function(){
			mj.hideLoading();
		});
}

function doRejectTask(taskId, callback) {
	mj.showLoading();
	mj.post(MJ_URL.TASK_A_REJECT.mjFormat(taskId), {}, 
		function(){
			mj.alert('任务已被拒绝', function() {
				callback && callback();
			});
		},
		function(xhr){
			showResult(xhr, LOST_NETWORK_CONNECTION);
		},
		function(){
			mj.hideLoading();
		});
}

function doCompleteTask(taskId, callback) {
	mj.showLoading();
	mj.post(MJ_URL.TASK_A_COMPLETE.mjFormat(taskId), {}, 
		function(){
			mj.alert('完成任务成功', function() {
				callback && callback();
			});
		},
		function(xhr){
			showResult(xhr, LOST_NETWORK_CONNECTION);
		},
		function(){
			mj.hideLoading();
		});
}

function showTaskDetailView(objItem, isMine) {
	var taskId = objItem.getAttribute('pid');
	var taskName = objItem.getAttribute('pname');
	var taskType = objItem.getAttribute('ptype');
	var taskStatus = Number(objItem.getAttribute('pstatus'));
	doShowTaskDetailView({
		id: taskId,
		name: taskName,
		taskType: taskType,
		status: taskStatus
	}, isMine);
}

function doShowTaskDetailView(task, isMine) {
	var taskId = task.id;
	var taskName = task.name;
	var taskType = task.taskType;
	var taskStatus = task.status;
	var href = TASK_TYPE_DEPARTMENT==Number(taskType) ? 'task_department_detail_temp.html':'task_project_detail_temp.html';
	var isBars = false;
	var barsIcon = '';
	var canEdit;
	canEdit = isMine && (TASK_STATUS_CREATED==taskStatus || TASK_STATUS_REJECTED==taskStatus);
	canEdit = canEdit || (!isMine && TASK_STATUS_TASK==taskStatus);
//	if(canEdit) {
//		isBars = true;
//		barsIcon = 'mui-icon mui-icon-compose';
//	} 
	pushWebView({
		webType: 'newWebview_Third',
		id: href,
		href: 'views/task/' + href,
		aniShow: 'slide-in-right',
		title: '详情',
		isBars: false,
		barsIcon: false,
		extendOptions: {
			taskId: taskId,
			noCache: true
		}
	})
}

//新版app脚本
//计划列表模板
function generatePLanList(list){
	var listHtml = '';
	for(var i=0;i<list.length;i++) {
		var listItem;
		listItem = list[i];
		var startTime = (new Date(listItem.startTime)).format('yyyy.MM.dd hh:mm');
		var endTime = (new Date(listItem.endTime)).format('yyyy.MM.dd hh:mm');
		console.log(JSON.stringify(list[i]))
		listHtml += '<div class="hr-list-block hr-list-item" pid="'+list[i].id+'" pname="'+list[i].name+'" ptype="'+list[i].taskType+'" pstatus="'+list[i].status+'">'+
		            '	<div class="hr-list-block-info">'+
	            	'		<div class="hr-list-first-line">'+
	            	'			<div class="hr-list-first-left">'+
	           		'				<span class="hr-list-name">'+list[i].name+'</span>'+
	           		'				<span class="hr-list-text-size hr-list-importance"></span>'+
	           		'			</div>'+
	           		'			<span class="hr-list-text-mini-size hr-list-right hr-list-bold">'+
	           		'				<span class="mui-icon iconfont icon-jihua-jihualeixing hr-list-right-icon"></span>'+planType[list[i].cycle]+''+
		            '			</span>'+
              	'		</div>'+	
            		'		<div class="hr-list-second-line hr-list-light-color">'+																
								'			<span class="hr-list-text-size">'+ startTime + ' ~ </span> '+
								'			<span class="hr-list-text-size">' + endTime +'</span>'+
								'		</div>'+				    
            		'		<div id="hrListActionLine" class="hr-list-third-line">'+
              	'			<span class="hr-list-text-block">'+
              	'				<span>负责人：</span>'+
              	'				<span>'+list[i].ownerName+'</span>'+
              	'			</span>'+
              	'			<span class="hr-list-text-block">'+
              	'				<span>审核人：</span>'+
								'				<span>'+list[i].reviewerName+'</span>'+
              	'			</span>'+
              	'		</div>'+			                 			                    				                    	
              	'	</div>'+
        			'</div>';
    }
	return listHtml;
}

//任务列表模板
function generateTaskList(list) {
	var listHtml = '';
	for(var i=0;i<list.length;i++) {
		var listItem;
		listItem = list[i];
		var startTime = (new Date(listItem.startTime)).format('yyyy.MM.dd hh:mm');
		var endTime = (new Date(listItem.endTime)).format('yyyy.MM.dd hh:mm');
		var showProgress = TASK_STATUS_TASK == listItem.status ? 'block' : 'none';
		listHtml += '<div class="hr-list-block hr-list-item" pid="'+listItem.id+'" pname="'+listItem.name+'" ptype="'+listItem.taskType+'" pstatus="'+listItem.status+'">'+
		            '	<div class="hr-list-block-info">'+
	            	'		<div class="hr-list-first-line">'+
	            	'			<div class="hr-list-first-left">'+
	           		'				<span class="hr-list-name">'+listItem.name+'</span>'+
	           		'				<span class="hr-list-text-size hr-list-importance"></span>'+
	           		'			</div>'+
	           		'			<span class="hr-list-text-mini-size hr-list-right hr-list-right-importance hr-list-bold" style="display:'+ showProgress +'">'+
	           		'				<span class="mui-icon iconfont icon-icon29 hr-list-right-icon"></span>'+listItem.progress+'%'+
		            '			</span>'+
                	'		</div>'+	
            		'		<div class="hr-list-second-line hr-list-light-color">'+																
					'			<span class="hr-list-text-size">'+ startTime + ' ~ </span>'+
					'			<span class="hr-list-text-size">' + endTime +'</span>'+
					'		</div>'+				    
            		'		<div id="hrListActionLine" class="hr-list-third-line">'+
                	'			<span class="hr-list-text-block">'+
                	'				<span>负责人：</span>'+
                	'				<span>'+listItem.ownerName+'</span>'+
                	'			</span>'+
                	'			<span class="hr-list-text-block">'+
                	'				<span>审核人：</span>'+
			            '				<span>'+listItem.reviewerName+'</span>'+
                	'			</span>'+
                	'		</div>'+			                 			                    				                    	
                	'	</div>'+
        			'</div>';
    }
	return listHtml;
}

//编辑页知会人模板
function getEditViewNotifierList(list){
	var listHtml='';
	for(var i=0;i<list.length;i++){
		listHtml +=
					'<li class="mui-table-view-cell no-left-table-view-cell" uid="'+i+'">'+
					'	<span class="create-left-text">员工</span>'+
					'	<span class="mui-pull-right">'+
					'		<span id="selectedName">'+list[i].userName+'</span>'+
					'		<span id="btnDeleteItem" class="mui-icon iconfont icon-baoxiaomingxi-jian btn-delete-item btn-notifier-delete-icon"></span>'+
					'	</span>'+
					'</li>';
	}
	return listHtml;
}

//任务打分人创建/编辑模板
function getScorerItemForEdit(scorerName,scorerWeight,isReviewer,isFinal){
	var itemHtml = 	'<div class="mui-input-row mui-radio mui-left task-radio-row width-half">'+
									'	<label>'+
									'		<span class="create-left-text">'+scorerName+'</span>'+
									'	</label>'+
									'	<input name="isFinal" type="radio" class="final-scorer-checked" ' + (isFinal ? 'checked' : '') + '>'+
									'</div>'+
									'	<span class="hr-create-input-wrapper mui-pull-right width-half">'+
									'		<input class="scorer-input-weight" type="number" pattern="\d*" value="'+scorerWeight+'"/>&nbsp;&#37;';
	if(!isReviewer) itemHtml += '<span class="mui-icon iconfont icon-baoxiaomingxi-jian btn-delete-item btn-notifier-delete-icon"></span>';
	itemHtml +=		'	</span>';
	return itemHtml;
}

function getScorerListForEdit(list){
	var listHtml='';
	for(var i=0;i<list.length;i++){
		listHtml += '<li class="mui-table-view-cell no-left-table-view-cell task-scorer-item" sid="'+i+'" style="">';
	  listHtml += getScorerItemForEdit(list[i].scorerName,list[i].weight,list[i].isReviewer,list[i].isFinal);
		listHtml += '</li>';
	}
	return listHtml;
}
function getScorerListForModify(list){
	var listHtml='';
	for(var i=0;i<list.length;i++){
		listHtml += '<li class="mui-table-view-cell no-left-table-view-cell" sid="'+i+'">'+
					'	<span class="create-left-text">'+list[i].scorerName+'</span>'+
					'	<span class="hr-create-input-wrapper mui-pull-right">'+list[i].weight+'%</span>'+
					'</li>';
	}
	return listHtml;
}

//任务进度列表模板
function generateProgressList(list) {
	var listHtml = '';
	for(var i=0;i<list.length;i++) {
		listHtml += generateProgressItem(list[i]);
	}
	return listHtml;
}	

function generateProgressItem(listItem){
	var createTime = (new Date(listItem.createDate)).format('yyyy-MM-dd hh:mm');
	var listHtml='';
	listHtml +=	'<li class="mui-table-view-cell hr-list-light-color">'+
				'<div class="mui-pull-right">'+
				'<div class="progress-basic">'+
				'	<span class="progress-time">'+createTime+'</span>~'+
				'	<span class="progress-num">'+listItem.progressPer+'%</span>'+	
				'</div>'+
				'<div class="mui-pull-right progress-ds">'+listItem.progressTxt+'</div>	'+	
				'</div>';
	if(listItem.from && listItem.from == FROM_APP && listItem.addr){
		listHtml +=	'<div class="mui-pull-right progress-addr"><span class="mui-icon mui-icon-location"></span><span>'+listItem.addr+'</span></div>	';
	}
				
	listHtml +=	'</div>'+
				'</li>';
	return listHtml;
}

//任务历史打分列表模板
function generateScoreListForCheck(list){
	var listHtml = '';
	for(var i=0;i<list.length;i++) {
		listHtml += generateScoreItemForCheck(list[i]);
	}
	return listHtml;
}

function generateScoreItemForCheck(listItem){
	var listHtml='';
	var finalScorer = '';
	if(listItem.isFinal){
		finalScorer = '(最终打分人)';
	}
	listHtml +=	'<li class="mui-table-view-cell hr-list-light-color">'+
							'	<div>'+
							'		<div class="mui-pull-left" style="width:60%">'+
							'			<span><b>'+listItem.scorerName+ finalScorer+'</b></span>:'+
							'			<span>&#40;'+listItem.weight+'&#37;&#41;</span>'+
							'		</div>'+
							'		<div class="mui-pull-right right-lable" style="width:40%">'+
							'			<span>未打分</span>'+
							'		</div>';
							
	return listHtml;
}

function generateScoreListForEdit(list){
	var listHtml = '';
	for(var i=0;i<list.length;i++) {
		listHtml += generateScoreItemForEdit(list[i]);
	}
	return listHtml;
}

function generateScoreItemForEdit(listItem){
	var scoreTime;
	if(listItem.scoreTime){
		scoreTime = (new Date(listItem.scoreTime)).format('yyyy-MM-dd hh:mm');
	}
	var finalScorer = '';
	if(listItem.isFinal){
		finalScorer = '(最终打分人)';
	}
	var listHtml='';
	listHtml +=	'<li class="mui-table-view-cell hr-list-light-color">'+
							'	<div>'+
							'		<div class="mui-pull-left" style="width:60%">'+
							'			<span><b>'+listItem.scorerName + finalScorer+'</b></span>:'+
							'			<span>&#40;'+listItem.weight+'&#37;&#41;</span>'+
							'		</div>';
	if(listItem.scoreStatus == TASK_SCORER_NO_SCORE){
		listHtml +=	'		<div class="mui-pull-right left-main" style="width:40%">'+
								'			<span>未打分</span>'+
								'		</div>';
	}
	if(listItem.scoreStatus == TASK_SCORER_SCORED){
		listHtml +=	'		<div class="mui-pull-right" style="width:40%">'+
								'			<span><b>'+listItem.score+'</b>分</span>'+
								'		</div>'+
								'		<div class="mui-pull-right">'+
								'			<span>'+listItem.scoreNote+'</span>'+
								'		</div>'+
								'		<div class="mui-pull-right">'+
								'			<span>'+scoreTime+'</span>'+
								'		</div>';
	}
		
	listHtml +=	'	</div>'+
							'</li>';
	return listHtml;
}

//任务回复列表模板
function generateReplyList(list) {
	var listHtml = '';
	for(var i=0;i<list.length;i++) {
		listHtml += generateReplyItem(list[i]);
	}
	return listHtml;
}	

function generateReplyItem(listItem){
	var createTime = (new Date(listItem.createDate)).format('yyyy-MM-dd hh:mm');
	var listHtml='';
	listHtml +=	'<li class="mui-table-view-cell hr-list-light-color">'+
							'	<div class="mui-pull-right reply-wrapper">'+
							'		<div class="reply-basic">'+
							'			<span class="reply-time">'+createTime+'</span>'+
							'		</div>'+
							'		<div class="reply-ds">'+
							'			<span class="reply-name"><b>'+listItem.senderName+'</b></span>:'+
							'			<span class="reply-txt">'+listItem.note+'</span>'+
							'		</div>'+
							'	</div>'+
							'</li>';
	return listHtml;
}

//遮罩层
function initMask() {
	mask = mui.createMask(function(){
		mui(".mui-modal").each(function(){
			this.classList.remove('mui-active')
		});
 	});
}
	
//模态框呈现
function showTaskViewSelectModalMask(obj){
	mask.show();
	switch(obj){
		case 'DEPARTMENT':
			document.getElementById('departmentSelectModal').classList.add('mui-active');
			break;
		case 'OWNER':
		   document.getElementById('ownerSelectModal').classList.add('mui-active');
		   break;
		case 'SCORER':
		   document.getElementById('scorerSelectModal').classList.add('mui-active');
		   break;
		default:
		   break;
	}
}
	
//模态框隐藏
function hideTaskViewSelectModalMask(obj){
	mask.close();
	switch(obj){
		case 'DEPARTMENT':
			document.getElementById('departmentSelectModal').classList.remove('mui-active');
			break;
		case 'OWNER':
		   document.getElementById('ownerSelectModal').classList.remove('mui-active');
		   break;
		case 'SCORER':
		   document.getElementById('scorerSelectModal').classList.remove('mui-active');
		   break;
		default:
		   break;
	}
}
	
//弹出框隐藏
function hideTaskViewPopover(){
	mui('.mui-popover').on('tap','.btn-bill-popover-close',function(){
		mui('.mui-popover').popover('hide');
	});
}

//时间类型
function initCycleBookForTask(){
	var cycles=[
		{
			id: 1,
			name: '日计划'
		}, 
		{
			id: 2,
			name: '周计划'
		}, 
		{
			id: 3,
			name: '月计划'
		}, 
		{
			id: 4,
			name: '季计划'
		}, 
		{
			id: 5,
			name: '年计划'
		}, 
		{
			id: 6,
			name: '自定义'
		}
	];
	
	document.getElementById('showCycle').addEventListener('tap',function(){
    pushUserSelectWebView({
    	source:'CYCLE',
    	title:'请选择时间类型',
      param:{},
      showCycles:cycles,
      callback: function(selected){
        taskCycle=selected.id;
        document.getElementById('taskCycle').innerText = selected.name;
        
        if(taskCycle ==6){
					return false;
				}
        
				var timeRange = mj.changeCycle(Number(taskCycle));
				document.getElementById('startTime').innerText = timeRange.start;
        document.getElementById('endTime').innerText = timeRange.end;
      }
    });
  });
}

//所属部门
function initDepartmentByMgrBookForTask(opt){
	opt = opt || {};
	var isForPlan = opt.isForPlan || false;
	var departmentUrl = isForPlan ? MJ_URL.DEPT_LIST_BY_ME : MJ_URL.DEPT_API;
	document.getElementById('showTaskOwnerDepartment').addEventListener('tap',function(){
    pushUserSelectWebView({
    	source:'DEPARTMENT',
    	title:'请选择所属部门',
      param:{
      	url:departmentUrl
      },
      hasSpecial:false,
     	showDirectSub:false,
			splitByAccount: false,
			accountId: -1,
     	showDepartments:[],
      callback: function(selected){
        departmentId=selected.id;
        document.getElementById('departmentResult').innerText = selected.name;
        
        if(!isForPlan) {
        	document.getElementById('ownerResult').innerText = '';
					ownerId =-1;

					resetTaskScorers(scorerMap,'btnAddScorer','scorerList');
				}
      }
    });
  });
}

//负责人
function initOwnerBookForDepartmentTask(){
	var paramUrl='';
	var paramId=-1;
	document.getElementById('showTaskOwner').addEventListener('tap',function(){
		if (!departmentId || departmentId <= 0) {
			mui.toast('请先选择所属部门');
			return false;
		}

		paramUrl = MJ_URL.USER_LIST_BY_DEPT;
		paramId = departmentId;
		
    pushUserSelectWebView({
    	source:'USER',
    	title:'请选择负责人',
      param:{
      	url:paramUrl,
      	department:paramId
      },
      hasSpecial:false,
     	showSubSelect:false,
     	showAll:false,
     	autoLoad:false,
			showUsers:[],
      callback: function(selected){
        ownerId=selected.id;
        document.getElementById('ownerResult').innerText = selected.name;
				
				resetTaskScorers(scorerMap,'btnAddScorer','scorerList');
				
				renderDeptScorerMapForTaskForCreate(ownerId,TASK_FROM_TASK,'scorerList',function(scorers){
					scorerIndex = scorers.length;
					for(var i=0;i<scorerIndex;i++){
						scorerMap[i]={
							sid:i,
							scorerId:scorers[i].scorerId,
							scorerName:scorers[i].scorerName,
							weight:scorers[i].weight,
							isReviewer:scorers[i].isReviewer,
							isFinal:scorers[i].isFinal
						}
					}
					document.getElementById('btnAddScorer').style.display = 'block';
				});
      }
    });
  });
}

//项目负责人选择
function initOwnerBookForProjectTask(){
	document.getElementById('showTaskOwner').addEventListener('tap',function(){
		if(projectId==-1){
			mui.toast('请选择所属项目');
			return false;
		}
    pushUserSelectWebView({
    	source:'USER',
    	title:'请选择负责人',
      param:{
      	url:MJ_URL.USER_LIST_BY_PROJ,
      	project:projectId
      },
      hasSpecial:false,
      showSubSelect:false,
      showAll:false,
      autoLoad:false,
			showUsers:[],
      callback: function(selected){
        ownerId=selected.id;
        document.getElementById('ownerResult').innerText = selected.name;
				
				resetTaskScorers(scorerMap,'btnAddScorer','scorerList');
				
				renderProjScorerMapForTaskForCreate(projectId,ownerId,TASK_FROM_TASK,true,'scorerList',function(scorers){
					scorerIndex = scorers.length;
					for(var i=0;i<scorerIndex;i++){
						scorerMap[i]={
							sid:i,
							scorerId:scorers[i].scorerId,
							scorerName:scorers[i].scorerName,
							weight:scorers[i].weight,
							isReviewer:scorers[i].isReviewer,
							isFinal:scorers[i].isFinal
						}
					}
					
					document.getElementById('btnAddScorer').style.display = 'block';
				});
      }
    });
  });
}

//知会人部门选择
function initDepartmentSelectForNotifier(){
	initAllDepartmentBook({
  	departmentTapId:'btnShowDepartmentSelectModal',
  	departmentShowId:'departmentName',
  	title:'请选择部门',
  	showAll:false,
  	hasSpecial:false,
  	splitByAccount:false,
  	accountId:-1,
  	splitByOwn:false,
  },function(selected){
  	currentNotifier.department=selected.id;
		currentNotifier.departmentName=selected.name;
  });
}
	
//知会人员工选择
function initOwnerSelectForNotifier(){
	initAllUserBook({
	  userTapId:'btnShowOwnerSelectModal',
	  userShowId:'ownerName',
	  showAll:false,
	  hasSpecial:false,
	  showSubSelect:false
	}, function(selected){
	  currentNotifier.user=selected.id;
    currentNotifier.userName=selected.name;
	});
}
	
//增加知会人员工项
function initNotifier(){
	var notifierId;
	document.getElementById('btnAddNotifier').addEventListener('tap',function(){
		document.getElementById('ownerName').innerText = '';
		
		currentNotifierId  =-1;
		currentNotifier ={
			id:notifierId,
			user:-1
		}
	});
	
	document.getElementById('btnCompletePopoverSelect').addEventListener('tap',function(){
		if(currentNotifier.user ==-1){
			mui.toast('知会人信息不完整');
			document.getElementById('btnCompletePopoverSelect').classList.remove('btn-bill-popover-close');
			return false;
		}else{
			document.getElementById('btnCompletePopoverSelect').classList.add('btn-bill-popover-close');
		}
		notifierId = notifierLength++;
		var objName = document.getElementById('ownerName').innerText;
		var objUser = document.createElement('li');
		objUser.setAttribute('uid',notifierId);
		objUser.className = 'mui-table-view-cell';
		objUser.innerHTML =
						'<span class="create-left-text">员工</span>'+
						'<span class="mui-pull-right">'+
						'	<span id="selectedName">'+objName+'</span>'+
						'	<span id="btnDeleteItem" class="mui-icon iconfont icon-baoxiaomingxi-jian btn-delete-item btn-notifier-delete-icon"></span>'+
						'</span>';
						
		document.getElementById('notifierList').appendChild(objUser);
		
		var newNotifier={
			id:notifierId
		}
		currentNotifier =mui.extend(currentNotifier,newNotifier);
		notifierMap[notifierId]=currentNotifier;
	});
	
	mui('#notifierList').on('tap','#btnDeleteItem',function(){
		var objDeleteUser = this.parentNode.parentNode;
		var deleteId = this.parentNode.parentNode.getAttribute('uid');
		mui.confirm('确认删除该知会人？','删除知会人',['确认','取消'],function(e){
			if (e.index == 0) {
				if (objDeleteUser) {
					objDeleteUser.parentNode.removeChild(objDeleteUser);
					objDeleteUser = null;
				}
				delete notifierMap[deleteId];
			}
		});
	})
}

//重置任务打分人
function resetTaskScorers(scorerMap,btn,container){
	scorerMap=[];
	document.getElementById(btn).style.display = 'none';
	document.getElementById(container).innerHTML =''
}

//任务打分人调整
function initScorer(){
	//添加
	document.getElementById('btnAddScorer').addEventListener('tap',function(){
		document.getElementById('scorerName').innerText ='';
		document.getElementById('scoreWeight').value ='';
		
		currentScorerId = -1;
		currentScorer = {
			sid:scorerIndex,
			scorerId:-1,
			scorerName:'',
			weight:'',
			isReviewer:false,
			isFinal:false
		}
	});
	
	//删除
	mui('#scorerList').on('tap','.btn-delete-item',function(e){
		suspendEventBub(e);
		var objDeleteScorer = this.parentNode.parentNode;
		var deleteId = this.parentNode.parentNode.getAttribute('sid');
		mui.confirm('确认删除该任务打分人？','删除任务打分人',['确认','取消'],function(e){
			if (e.index == 0) {
				if (objDeleteScorer) {
					objDeleteScorer.parentNode.removeChild(objDeleteScorer);
					objDeleteScorer = null;
				}
				delete scorerMap[deleteId];
			}
		});
	});
	
	//权重输入
	mj.inputMoveToEnd('#scorerList', '.scorer-input-weight');
	mui('#scorerList').on('input','.scorer-input-weight',function(){
		var changeId = this.parentNode.parentNode.getAttribute('sid');
		var $this = this;
		$this.value = $this.value.replace(/\D/g,'');
		if($this.value >100){
			$this.value = 100;
		}
		var changeWeight = $this.value;
		scorerMap[changeId].weight = changeWeight;
	});
	
	//打分人选择
	var showScorerSelect;
	initAllUserBook({
    userTapId:'btnShowScorerSelectModal',
    userShowId:'scorerName',
    hasSpecial:false,
    prepare: function(){
      showScorerSelect = document.getElementById('btnShowScorerSelectModal').getAttribute('data-id');
    }
  }, function(selected){
    currentScorer.scorerId=selected.id;
    currentScorer.scorerName=selected.name;
  });
  
  //指定最终打分人
  mui('#scorerList').on('change','.final-scorer-checked',function(){
  	for(var key in scorerMap) scorerMap[key].isFinal = false;
  	if(this.checked){
  		var checkedId = this.parentNode.parentNode.getAttribute('sid');
			scorerMap[checkedId].isFinal = true;
	  }
	});
	
	//确认添加打分人
	document.getElementById('btnCompleteScorerSelect').addEventListener('tap',function(){
		currentScorer.weight = document.getElementById('scoreWeight').value;
	
		if(currentScorer.scorerId==-1 || currentScorer.weight=='' || currentScorer.weight==0){
			mui.toast('任务打分人信息不完整');
			document.getElementById('btnCompleteScorerSelect').classList.remove('btn-bill-popover-close');
			return false;
		}else{
			document.getElementById('btnCompleteScorerSelect').classList.add('btn-bill-popover-close');
		}
		
		//收回软键盘
		mj.fixAfterInput();
		
		var objScorerName = document.getElementById('scorerName').innerText;
		var objScoreWeight = document.getElementById('scoreWeight').value;
		var objScorer = document.createElement('li');
		objScorer.setAttribute('sid',currentScorer.sid);
		objScorer.className = 'mui-table-view-cell';
		objScorer.innerHTML = getScorerItemForEdit(objScorerName,objScoreWeight,false,false);
						
		document.getElementById('scorerList').appendChild(objScorer);
		
		scorerMap[scorerIndex++]=currentScorer;
	});
}

//部门任务打分人
function renderDeptScorerMapForTaskForCreate(userId,taskFrom,container,callback){
	var objScorerList = document.getElementById(container);
	mjQueryDeptScorerMapForTask(userId,taskFrom,function(data){
		objScorerList.innerHTML+=getScorerListForEdit(data);
		callback && callback(data);
	});
}

//项目任务打分人
function renderProjScorerMapForTaskForCreate(projectId,userId,taskFrom,imReviewer,container,callback){
	var objScorerList = document.getElementById(container);
	mjQueryProjScorerMapForTask(projectId,userId,taskFrom,function(data){
		if(imReviewer){
			mui.each(data,function(index,item){
				if(item.isReviewer){
					item.scorerName=mj.getNickName();
				}
			});
		}
		objScorerList.innerHTML+=getScorerListForEdit(data);
		callback && callback(data);
	});
}

//任务打分人编辑页
function renderScorerMapForTaskForEdit(container,scorers){
	scorerIndex = scorers.length;
	switch(taskStatus){
		case TASK_STATUS_COMPLETED:
			document.getElementById(container).innerHTML+=getScorerListForModify(scorers);
			break;
		case TASK_STATUS_TASK:
		default:
			document.getElementById(container).innerHTML+=getScorerListForEdit(scorers);
			break;
	}
	
	for(var i=0;i<scorerIndex;i++){
		scorerMap[i]={
			scorerId:scorers[i].scorerId,
			scorerName:scorers[i].scorerName,
			weight:scorers[i].weight,
			isReviewer:scorers[i].isReviewer,
			isFinal:scorers[i].isFinal,
			sid:i
		}
	}
}

//获取任务&计划详情
function mjQueryTasks(callback){
	mj.get(MJ_URL.TASK_API + taskId, {}, function(d){
		callback && callback(d);
	}, function(xhr){
		showResult(xhr, LOST_NETWORK_CONNECTION);
	});
}

//获取任务进度列表
function mjQueryTaskProgress(taskId,callback){
	mj.get(MJ_URL.TASK_F_PROGRESS.mjFormat(taskId), {}, function(d){
		callback && callback(d);
	}, function(xhr){
		showResult(xhr, LOST_NETWORK_CONNECTION);
	});
}

//获取任务打分人列表
function mjQueryTaskScore(taskId,callback,errCallback){
	mj.get(MJ_URL.TASK_A_SCORES.mjFormat(taskId), {}, function(d){
		callback && callback(d);
	}, function(xhr){
		showResult(xhr, LOST_NETWORK_CONNECTION);
		errCallback && errCallback();
	});
}

//获取任务回复列表
function mjQueryTaskReply(taskId,callback){
	mj.get(MJ_URL.TASK_F_REPLY.mjFormat(taskId), {}, function(d){
		callback && callback(d);
	}, function(xhr){
		showResult(xhr, LOST_NETWORK_CONNECTION);
	});
}

//获取部门任务打分人模板
function mjQueryDeptScorerMapForTask(userId,taskFrom,callback){
	mj.get(MJ_URL.TASK_SCORER_DEPT_MAPPING.mjFormat(userId,taskFrom), {}, function(d){
		callback && callback(d);
	}, function(xhr){
		showResult(xhr, LOST_NETWORK_CONNECTION);
	});
}

//获取项目任务打分人模板
function mjQueryProjScorerMapForTask(projectId,userId,taskFrom,callback){
	mj.get(MJ_URL.TASK_SCORER_PROJ_MAPPING.mjFormat(projectId, userId,taskFrom), {}, function(d){
		callback && callback(d);
	}, function(xhr){
		showResult(xhr, LOST_NETWORK_CONNECTION);
	});
}

//详情页操作按钮
function getTaskCurrentActionButtons(taskStatus,taskOwner,taskReviewer){
	switch(taskStatus) {
		case TASK_STATUS_CREATED:
	    if(taskOwner == mj.getId()){
    		document.getElementById('btnGroupEdit').style.display='block';
	    }
	    break;
		case TASK_STATUS_PLAN:
			if(taskOwner == mj.getId()){
				document.getElementById('btnGroupCancelUpload').style.display = 'block';
			}
			if(taskReviewer && taskReviewer == mj.getId()){
				document.getElementById('btnGroupReview').style.display = 'block';
			}
			break;
		case TASK_STATUS_REJECTED:
			if(taskOwner == mj.getId()){
				document.getElementById('btnGroupEdit').style.display='block';
			}
	    break;	
		case TASK_STATUS_TASK:
  		  document.getElementById('btnGroupReply').style.display='block';
	    if(taskOwner==mj.getId()){
    		  document.getElementById('btnGroupReply').classList.add('triple-button-wrapper');
    		  document.getElementById('btnGroupProgress').style.display='block';
    		  document.getElementById('btnGroupSplit').style.display='block';
	    }else if(taskReviewer && taskReviewer == mj.getId()){
    		  document.getElementById('btnGroupReply').classList.add('triple-button-wrapper');
    		  document.getElementById('btnGroupTerminate').style.display='block';
    		  document.getElementById('btnGroupModify').style.display='block';
	    }else{
    		  document.getElementById('btnGroupReply').classList.add('single-button-wrapper');
	    }
	    break;
		case TASK_STATUS_COMPLETED:
		case TASK_STATUS_TERMINATED:
		case TASK_STATUS_SCORED:
		default:
			break;
	}
}

function getTaskCompleteBtn(taskStatus, canScore){
	if(taskStatus != TASK_STATUS_COMPLETED){
		return;
	}
	document.getElementById('btnGroupReply').style.display='block';
	if(canScore){
		if(taskReviewer && taskReviewer == mj.getId()){
      document.getElementById('btnGroupModify').style.display='block';
      document.getElementById('btnGroupModify').classList.add('triple-button-wrapper');
      document.getElementById('btnGroupReply').classList.add('triple-button-wrapper');
			document.getElementById('btnGroupScore').style.display = 'block';
			document.getElementById('btnGroupScore').classList.add('triple-button-wrapper');
		}else{
			document.getElementById('btnGroupReply').classList.add('double-button-wrapper');
			document.getElementById('btnGroupScore').style.display = 'block';
			document.getElementById('btnGroupScore').classList.add('double-button-wrapper');
		}
	}else{
		document.getElementById('btnGroupReply').classList.add('single-button-wrapper');
	}
}

function bindPlanDetailButtonAction(){
	document.getElementById('btnDelete').addEventListener('tap',function(){
		mui.confirm('确认删除？','删除计划',['确认','取消'],function(e){
			if (e.index == 0) {
				detailViewDoDeletePlan(taskId);
			}
		});
	});
	
	document.getElementById('btnUpload').addEventListener('tap',function(){
		mui.confirm('确认上报计划？','上报计划',['上报','取消'],function(e){
			if (e.index == 0) {
				detailViewDoUploadPlan(taskId);
			}
		});
	});
	
	document.getElementById('btnEdit').addEventListener('tap',function(){
		showPlanEditView(taskId,taskType,taskStatus,TASK_FROM_PLAN);
	});
	
	document.getElementById('btnCancelUpload').addEventListener('tap',function(){
		mui.confirm('确认取消上报计划"'+taskName+'"？','取消上报计划',['确定','取消'],function(e){
			if (e.index == 0) {
				detailViewDoCancelPlan(taskId);
			}
		});
	});
	
	document.getElementById('btnReject').addEventListener('tap',function(e){
		suspendEventBub(e);
		e.detail.gesture.preventDefault();
		
		var postData = {};
		mj.prompt({ msg: '拒绝计划' }, function(e) {
			postData = {
				stateNote: e.value
			}
			mj.confirm({ msg: '确认拒绝计划"'+taskName+'"？' }, function() {
				//log('拒绝理由' + JSON.stringify(postData));
				detailViewDoRejectPlan(taskId,postData);
			})
		});
	});
	
	document.getElementById('btnApprove').addEventListener('tap',function(){
		mui.confirm('确认通过计划"'+taskName+'"？','通过计划',['确定','取消'],function(e){
			if (e.index == 0) {
				detailViewDoApprovePlan(taskId);
			}
		});
	});
}

//详情页完成任务
function bindBtnTerminateAction(){
	document.getElementById('btnTerminate').addEventListener('tap',function(){
		mui.confirm('确认终止任务"'+taskName+'"？','终止任务',['确定','取消'],function(e){
			if (e.index == 0) {
				detailViewDoTernimateTask(taskId);
			}
		});
	});
}

//任务审核后审核人更新任务
function bindBtnModifyAction(){
	document.getElementById('btnModify').addEventListener('tap',function(){
		showPlanEditView(taskId,taskType,taskStatus,TASK_FROM_TASK);
	});
}

function detailViewDoTernimateTask(taskId, callback) {
	mj.post(MJ_URL.TASK_A_COMPLETE.mjFormat(taskId), {}, function(){
		mui.toast('终止任务成功');
    mj.backAndRefresh();
	}, function(xhr) {
		showResult(xhr, LOST_NETWORK_CONNECTION);
		mj.hideLoading();
	});
}

//详情页报进度&获取进度列表
function getProgressList(taskId, callback) {
	mjQueryTaskProgress(taskId,function(o){
		if(o && o.status==0) {
			if(o.data.length>0) {
				var listHtml = generateProgressList(o.data);
				objProgressList.innerHTML = listHtml;
				oldProgress = o.data[o.data.length-1].progressPer;
			}
		} else {
			showFromCode(o.status);
		}
	});
}

function bindBtnProgressAction(){
	//首次显示地理位置
	document.getElementById('btnGroupProgress').addEventListener('tap',function(){
		getUserCurrentAddr('taskAddr',function(currentAddr,longitude,latitute){
			lon = longitude;
			lat = latitute;
			addr = currentAddr;
		});
		
	});
	
	//点击是否获取位置
	document.getElementById('addrWrapper').addEventListener('tap',function(){
		doActionChangeUserCurrentAddr('taskAddr',addr,function(){
				lon = '';
				lat = '';
				addr = '';
			},
			function(currentAddr,longitude,latitute){
			lon = longitude;
			lat = latitute;
			addr = currentAddr;
		});
	})
	
	document.getElementById('btnCompleteProgress').addEventListener('tap',function(){
		onCreateProgress();
	});
}

function onCreateProgress() {		
	var progressPer = document.getElementById("progressPer").value;
	var progressTxt = document.getElementById("progressTxt").value;
	
	var newProgress = {
		progressPer: progressPer,
		progressTxt: progressTxt,
		taskId: taskId,
		form:FROM_APP,
		lon:lon,
		lat:lat,
		addr:addr
	}
	
	if(progressPer<0 || progressPer>100 || progressTxt.trim()=='') {
		mj.alert('请输入正确进度值(0~100)和描述');
		return;
	}
	
	if(progressPer <= oldProgress){
		mj.alert('操作失败，当前任务进度无变化');
		return;
	}
	
	if(progressPer==100) {
		mj.confirm({
			msg: '当前进度为100%，提交后将不能修改进度，您是否确定任务已完成？',
			title: '任务进度确认'
		}, function() {
			doCreateProgress(newProgress);
		});
	} else {
		doCreateProgress(newProgress);
	}
}

function doCreateProgress(newProgress) {
	mj.showLoading();
	
	mj.post(MJ_URL.TASK_F_PROGRESS.mjFormat(taskId), newProgress, function(){
		mj.hideLoading();
		newProgress.createDate = new Date();
		objProgressList.innerHTML = generateProgressItem(newProgress) + objProgressList.innerHTML;
		document.getElementById("progressPer").value = '';
		document.getElementById("progressTxt").value = '';
		mui.toast('报进度成功');
		mj.refreshViewOfMine();
		mj.backAndRefresh();
	}, function(xhr) {
		mj.hideLoading();
		showResult(xhr, LOST_NETWORK_CONNECTION);
	});
}

//分解任务
function bindBtnSplitAction(task){
	document.getElementById('btnSplit').addEventListener('tap',function(){
		showSplitViewFromDetail(task);
	});
}

function showSplitViewFromDetail(task){
	var parentId = task.id;
	var parentName = task.name;
	var taskImportance = task.importance;
	var taskNotifiers = task.notifiers;
	var taskContent = task.content;
	var startTime = (new Date(task.startTime)).format('yyyy-MM-dd hh:mm');
	var endTime = (new Date(task.endTime)).format('yyyy-MM-dd hh:mm');
	
	var projectId = task.projectId ? task.projectId :'-1';
	var projectName = task.projectName ? task.projectName :'';
	
	var taskType = task.taskType;
	
	var splitUrl = Number(taskType == TASK_TYPE_DEPARTMENT) ? 'task_department_split_temp.html' : 'task_project_split_temp.html';
	pushWebView({
		webType: 'newWebview_Fourth',
		id: splitUrl,
		href: 'views/task/'+splitUrl,
		aniShow: 'slide-in-right',
		title: "分解任务",
		isBars: false,
		barsIcon: '',
		extendOptions: {
			noCache: true,
			parentId:parentId,
			parentName:parentName,
			importance:taskImportance,
			startTime:startTime,
			endTime:endTime,
			projectId:projectId,
			projectName:projectName,
			notifiers:taskNotifiers,
			content:taskContent
		}
	});
}

//详情页打分&&获取历史打分列表
function mjSortScoreStatus(array){
	array.sort(function(a,b){
		return a.scoreStatus - b.scoreStatus;
	});
	return array;
}

function getScoreList(taskId,taskStatus,callback){
	var canScore = false;
	var scoreLength =0;
	mjQueryTaskScore(taskId,function(o){
		if(o && o.status==SYSTEM_SUCCEED) {
			scoreLength = o.data.length;
			if(scoreLength>0) {
				var newData = mjSortScoreStatus(o.data);
				var listHtml = '';
				switch(taskStatus){
					case TASK_STATUS_CREATED:
	        case TASK_STATUS_PLAN:
	        case TASK_STATUS_REJECTED:
	        case TASK_STATUS_TASK:
	        case TASK_STATUS_TERMINATED:
	      		 	listHtml = generateScoreListForCheck(newData);
	      		 	break;
	      		case TASK_STATUS_COMPLETED:
	      			mui.each(o.data,function(index,item){
							if(item.scorerId == mj.getId() && item.scoreStatus==TASK_SCORER_NO_SCORE){
								canScore = true;
							}
						});
						listHtml = generateScoreListForEdit(newData);
						break;
	    			case TASK_STATUS_SCORED:
	    				listHtml = generateScoreListForEdit(newData);
	    				break;
	    			default:
	    				break;
				}
				objScoreList.innerHTML = listHtml;
				callback && callback(canScore);
			}
		} else {
			showFromCode(o.status);
			callback && callback(false);
		}
	}, function(){
		callback && callback(false);
	});
}

function bindBtnScoreAction(){
	document.getElementById('btnCompleteScore').addEventListener('tap',function(){
		scoreTask();
	});
}

function scoreTask() {
	var scoreNum = document.getElementById("scoreNum").value;
	var scoreComment = document.getElementById("scoreComment").value;
	
	if(scoreNum =='') {
		mui.toast('请输入分值');
		return;
	}
	
	if(isNaN(scoreNum) || scoreNum<0 || scoreNum>100) {
		mui.toast('分值输入错误，请输入1-100之间的整数值');
		return;
	}
	
	if(scoreComment.trim()=='') {
		mui.toast('请输入备注');
		return;
	}
	
	mui('#middleScorePopover').popover('hide');
	
	mj.confirm({msg:'确认打分？'},function(e){
		var newScore = {
			score: scoreNum,
			scoreNote: scoreComment
		};
		
		doScoreTask(taskId, newScore, function() {
			mj.refreshViewOfMine();
			mj.reload(true);
		});
	});		
}

function doScoreTask(taskId, postData, callback) {
	mj.showLoading();
	mj.post(MJ_URL.TASK_A_SCORES.mjFormat(taskId), postData, function(){
		mj.hideLoading();
		mj.alert('打分成功', function() {
			callback && callback();
		});
	}, function(xhr) {
		mj.hideLoading();
		showResult(xhr, LOST_NETWORK_CONNECTION);
	});
}

//详情页任务回复&&获取任务回复列表
function getReplyList(taskId, callback) {
	mjQueryTaskReply(taskId,function(o){
		if(o && o.status==0) {
			if(o.data.length>0) {
				var listHtml = generateReplyList(o.data);
				objReplyList.innerHTML = listHtml;
			}
		} else {
			showFromCode(o.status);
		}
	});
}

function bindBtnReplyAction(){
	document.getElementById('btnCompleteReply').addEventListener('tap',function(){
		onCreateReply();
	});
}

function onCreateReply(){
	var replyTxt = document.getElementById('replyTxt').value;
	var newReply = {
		taskId:taskId,
		note:replyTxt
	}
	
	if(replyTxt.trim()=='') {
		mj.alert('请输入回复内容');
		return;
	}
	
	doCreateReply(newReply);
}

function doCreateReply(newReply){
	mj.showLoading();
	
	mj.post(MJ_URL.TASK_F_REPLY.mjFormat(taskId), newReply, function(){
		mj.hideLoading();
		newReply.createDate = new Date();
		newReply.senderName = mj.getNickName();
		objReplyList.innerHTML = generateReplyItem(newReply) + objReplyList.innerHTML;
		document.getElementById("replyTxt").value = '';
		mui.toast('任务回复成功');
	}, function(xhr) {
		mj.hideLoading();
		showResult(xhr, LOST_NETWORK_CONNECTION);
	});
}

//详情页上报计划
function detailViewDoUploadPlan(taskId){
	mj.post(MJ_URL.TASK_A_UP.mjFormat(taskId), {}, function(){
		mui.toast('计划上报成功');
	    mj.refreshViewOfMine();
	    mj.backAndRefresh();
	}, function(xhr) {
//		mui.toast('计划上报失败，请重试');
		showResult(xhr, LOST_NETWORK_CONNECTION);
		mj.hideLoading();
	});
}

//详情页删除计划
function detailViewDoDeletePlan(taskId){
	mj.post(MJ_URL.TASK_A_DELETE.mjFormat(taskId), {}, function(){
		mui.toast('删除计划成功');
		mj.refreshViewOfMine();
	    mj.backAndRefresh();
	}, function(xhr) {
//		mui.toast('删除计划失败，请重试');
		showResult(xhr, LOST_NETWORK_CONNECTION);
		mj.hideLoading();
	});
}

//详情页取消上报计划
function detailViewDoCancelPlan(taskId){
	mj.post(MJ_URL.TASK_A_CANCEL.mjFormat(taskId), {}, function(){
		mui.toast('计划取消上报成功');
	    mj.refreshViewOfMine();
	    mj.backAndRefresh();
	}, function(xhr) {
//		mui.toast('取消上报计划失败，请重试');
		showResult(xhr, LOST_NETWORK_CONNECTION);
		mj.hideLoading();
	});
}

//详情页拒绝计划
function detailViewDoRejectPlan(taskId,postData,callback){
	mj.post(MJ_URL.TASK_A_REJECT.mjFormat(taskId), postData, function(){
		mui.toast('拒绝计划成功');
		mj.refreshViewOfMine();
    mj.backAndRefresh();
	}, function(xhr) {
		showResult(xhr, LOST_NETWORK_CONNECTION);
		mj.hideLoading();
	});
}

function detailViewDoApprovePlan(taskId){
	mj.post(MJ_URL.TASK_A_APPROVE.mjFormat(taskId), {}, function(){
		mui.toast('通过计划成功');
		mj.refreshViewOfMine();
		mj.backAndRefresh();
	}, function(xhr) {
		showResult(xhr, LOST_NETWORK_CONNECTION);
		mj.hideLoading();
	});
}

//详情页跳转到编辑页
function showPlanEditView(taskId,taskType,taskStatus,taskFrom){
	var isBars = false;
	var barsIcon = '';
	var href = TASK_TYPE_DEPARTMENT==Number(taskType) ? 'plan_department_edit_temp.html':'plan_project_edit_temp.html';
	var title = taskFrom == TASK_FROM_PLAN ? '计划编辑' : '任务更新' ;
	pushWebView({
		webType: 'newWebview_Fourth',
		id: href,
		href: 'views/plan/' + href,
		aniShow: 'slide-in-right',
		title: title,
		isBars: false,
		barsIcon: '',
		extendOptions: {
			taskId: taskId,
			taskStatus:taskStatus,
			taskFrom:taskFrom,
			noCache: true
		}
	})
}

//验证任务完整
function checkTaskModel(postData,postItem){
	var valid =true;
	var validMsg = '';
	
	mui.each(postItem,function(index,item){
		switch(item){
			case 'name':
		        if (postData[item]=='') {
		            valid = false;
		            validMsg = '请输入名称';
		            return false;
		        }
		        break;
	        case 'importance':
		        if (postData[item]=='') {
		            valid = false;
		            validMsg = '请输入重要性分值';
		            return false;
		        }
		        break;
	        case 'content':
		        if (postData[item]=='') {
		            valid = false;
		            validMsg = '请输入内容';
		            return false;
		        }
		        break;
	        case 'cycle':
			    if(!(postData[item] > 0)){
			    	valid = false;
	                validMsg = '请选择时间类型';
	                return false;  	
			    }
			    break;
			case 'projectId':
			    if(!(postData[item] > 0)){
			    	valid = false;
	                validMsg = '请选择所属项目';
	                return false;  	
			    }
			    break;
		    case 'starttime':
		        if (postData[item]=='') {
		            valid = false;
		            validMsg = '请选择开始时间';
		            return false;
		        }
		        break;
	        case 'endtime':
		        if (postData[item]=='') {
		            valid = false;
		            validMsg = '请选择结束时间';
		            return false;
		        }
		        break;
		    case 'departmentId':
			    if(!(postData[item] > 0)){
			    	valid = false;
	                validMsg = '请选择所属部门';
	                return false;  	
			    }
			    break;
		    case 'owner':
			    if(!(postData[item] > 0)){
			    	valid = false;
	                validMsg = '请选择负责人';
	                return false;  	
			    }
			    break;
			default:
            break;
	    }
		});
		if(!valid) {
	        mui.toast(validMsg);
	    }
	    return valid;
}

function canUploadAttach(task) {
	return TASK_STATUS_CREATED==task.status || TASK_STATUS_PLAN==task.status || TASK_STATUS_TASK==task.status || TASK_STATUS_REJECTED==task.status;
}

function renderCreateTaskAttaches() {
    prepareUpload('#btnAddAttach', 'attachWrapper', 'task', 0, '/api/m/tasks/attach/upload','/api/m/tasks/attach/delete',mj.getCompress(),mj.getMultiple());
}

function fnGetTaskAttachUrl(attachId){
	return '/api/m/tasks/attach/download?id='+attachId;
}

function fnGetTaskAttachSavePath(attachId, attachExt) {
	return '_downloads/image/' + mj.getId() + '_attach_' + attachId + attachExt;
}

function renderTaskAttaches(task) {
	var canUpload = canUploadAttach(task);
    if(canUpload) {
        document.getElementById('btnAddAttach').style.display = 'block';
        prepareUpload('#btnAddAttach', 'attachWrapper', 'task', taskId, '/api/m/tasks/attach/upload','/api/m/tasks/attach/delete',mj.getCompress(),mj.getMultiple());
    }
    
    mj.get(MJ_URL.TASK_ATTACH_LIST+taskId, {}, function(d){
  		var item;
  		var defaultFileImg= "../../@/img/file/file_sm.png";
  		
  		for(var i=0;i<d.length;i++){
  			item = d[i];
  			
  			var isImg = imgFilter.test(item.ext);
  			var imgName = item.name;
  			var attachExt = imgName.substr(imgName.lastIndexOf('.'));
  			
  			if(isImg){
  				var loadUrl = fnGetTaskAttachUrl(item.id);
  				var relativePath = fnGetTaskAttachSavePath(item.id, attachExt);
  				doGetAttach(loadUrl, relativePath, imgName, 'attachWrapper',item.id);
  			} else {
  				var imgDom = setImgFromLocal(defaultFileImg,imgName,'attachWrapper',item.id);
				imgDom.setAttribute('vi', item.id);
				imgDom.setAttribute('vt', attachExt);
				
				var img = imgDom.getElementsByTagName('img');
				for (var j=0;j<img.length;j++) {
					img[j].removeAttribute('data-preview-src');
					img[j].removeAttribute('data-preview-group');
				}
			
				imgDom.addEventListener('tap',function(){
					var attachId = this.getAttribute('vi');
					var attachExt = this.getAttribute('vt');
					
	  					var relativePath = fnGetTaskAttachSavePath(attachId, attachExt);
					plus.io.resolveLocalFileSystemURL(relativePath, function(entry) {
						log("附件已存在,地址:" + relativePath);
						showAttach(relativePath);
				    }, function(e) {
				    		var loadUrl = fnGetTaskAttachUrl(attachId);
				    		mj.download(loadUrl, relativePath, function(succeed) {
							if(succeed) {
								log("附件已下载,地址:" + relativePath);
								showAttach(relativePath);
							}
						});
				    });
				});
			}
		}
  }, function(){
  });
}

function showAttach(relativePath){
	var imgUrl = 'file://' + plus.io.convertLocalFileSystemURL(relativePath);
	
	plus.runtime.openFile(imgUrl, {}, function(e) {
		mui.toast("无法打开此文件：" + e.emssage);
	});
}

//addr
function doActionChangeUserCurrentAddr(selector,currentAddr,noAddrCallback,addrCallback){
	var $addr = document.getElementById(selector);
	
	if($addr.innerText === currentAddr){
		$addr.innerText = '获取所在位置';
		addrCallback && addrCallback();
	}else{
		getUserCurrentAddr(selector,function(currentAddr,longitude,latitute){
			addrCallback && addrCallback(currentAddr,longitude,latitute);
		});
	}
	
}

function getUserCurrentAddr(selector,callback){
	plus.geolocation.getCurrentPosition(function(p){
//		var lnglatXY = new AMap.LngLat(p.coords.longitude,p.coords.latitude);
		var addrGCj = GPS.gcj_encrypt(p.coords.latitude, p.coords.longitude);
		var addrWGS = GPS.gcj_decrypt_exact(addrGCj['lat'], addrGCj['lon']);
		var lnglatXY = mui.os.ios ? new AMap.LngLat(addrGCj['lon'],addrGCj['lat']) :new AMap.LngLat(addrWGS['lon'],addrWGS['lat']);
		
		var latitute; 
		var longitude;
		var currentAddr;
		
		var geocoder = new AMap.Geocoder({
  	 	radius: 50
    });
    geocoder.getAddress(lnglatXY, function(status, result) {
      if (status === 'complete' && result.info === 'OK') {
        currentAddr = result.regeocode.formattedAddress;
        latitute = lnglatXY.getLat();
        longitude = lnglatXY.getLng();
        document.getElementById(selector).innerText = result.regeocode.formattedAddress;
        
        callback && callback(currentAddr,longitude,latitute);
          
      }else{
      	mui.toast(LOST_NETWORK_CONNECTION);
      }
    });   
	}, function(e){
    switch(e.code) {
      case e.PERMISSION_DENIED:
        //mui.toast('User denied the request for Geolocation.');
        mui.toast('访问权限被拒绝.');
        break;
      case e.POSITION_UNAVAILABLE:
        //mui.toast('Location information is unavailable.');
        mui.toast('位置信息不可用.');
        break;
      case e.TIMEOUT:
        //mui.toast('The request to get user location timed out.');
        mui.toast('获取位置信息超时.');
        break;
      case e.UNKNOWN_ERROR:
        //mui.toast('An unknown error occurred.');
        mui.toast('获取位置错误：'+e.code);
        break;
      }
	},{geocode:true,provider: 'amap'});
}

//action
function sliderRenderTaskActionTab(taskId,task,$container,callback){
	document.getElementById('slider').addEventListener('slide', function(e) {
		if(e.detail.slideNumber === 1) {
			if(taskActionActive){
				return ;
			}
			taskActionActive = true;
			renderTaskActions($container,taskId,task,taskActionActive);
		}
	});
}

function getTaskActionTemplateList(task) {
	var listHtml =
		'<div class="bill-show-operate-vertical">' +
		'	<table>' +
		'		<tbody>';
	var listItem;
	mui.each(task.actions, function(index, item) {
		listItem = item;
		var createDate = '';
		var createDateMinute = '';
		if(listItem.createDate) {
			var tmpCreateDate = new Date(listItem.createDate);
			createDate = tmpCreateDate.format('yyyy-MM-dd');
			createDateMinute = tmpCreateDate.format('hh:mm');
		}
		listHtml += '<tr>' +
			'	<td class="right_td">' +
			'		<div class="date bill-show-operate-text">' + createDate + '<span class="operater-time-text">' + createDateMinute + '</span> ' +
			'		</div>' +
			'		<div class="right_box">' +
			'			<div class="state">' +
			'				<div>' + mjShowTaskActionNew(item, task.task) + '</div>' +
			'			</div>' +
			'			<div class="name">' +
			'				<span>操作人：</span>' +
			'				<span>' + listItem.userName + '</span>' +
			'				<span>(' + mjShowAction(listItem.action) + ')</span>' +
			'			</div>' +
			'		</div>' +
			'	</td>' +
			'</tr>';
	});
	listHtml += '</tbody></table></div>'
	return listHtml;
}

function renderTaskActions($container,taskId,task,taskActionActive){
	mj.get(MJ_URL.TASK_F_ACTIONS.mjFormat(taskId), {}, function(d) {
		var taskActions = {
			actions: d,
			task: task
		};
		$container.innerHTML = getTaskActionTemplateList(taskActions);
	},function() {});
}

function mjShowTaskActionNew(action,task){
	var str = '';
    var curData = action.curData;
    if(!curData) return str;
    switch(action.action){
      case ACTION_TASK_CREATE:
      case ACTION_TASK_UPLOAD:
      case ACTION_TASK_CREATE_UPLOAD:
      case ACTION_TASK_ASSIGN:
      case ACTION_TASK_APPROVE:
      case ACTION_TASK_REJECT:
      case ACTION_TASK_UPLOAD_ATTACH:
      case ACTION_TASK_DELETE_ATTACH:
      case ACTION_TASK_PROGRESS:
      	return str;
      case ACTION_TASK_TERMINATE:
        return '<div class="action-data-item">' + curData + '</div>';
      case ACTION_TASK_SCORE:
        curData = mui.parseJSON(curData);
        return '<div class="action-data-item">' + curData.score + ', ' + curData.scoreNote + '</div>';
      case ACTION_TASK_UPDATE:
        curData = mui.parseJSON(curData);
        var hasNotifiers = false;
        mui.each(curData, function(index, item) {
        	 
          switch(index) {
            case 'name':
                str += '<div class="action-data-item">名称:' + item + '</div>';break;
            case 'content':
                str += '<div class="action-data-item">内容:' + item + '</div>';break;
            case 'cycle':
                str += '<div class="action-data-item">时间安排:' +planType[item] + '</div>';break;
            case 'importance':
                str += '<div class="action-data-item">重要程度:' + item + '</div>';break;
            case 'startTime':
                str += '<div class="action-data-item">开始时间:' + new Date(item).format('yyyy-MM-dd hh:mm') + '</div>';break;
            case 'endTime':
                str += '<div class="action-data-item">结束时间:' + new Date(item).format('yyyy-MM-dd hh:mm') + '</div>';break;
            case 'notifiers':
            		hasNotifiers = true;
                mui.each(item, function(index,notifier) {
                    str += '<div class="action-data-item">知会人ID:' + notifier.userId + '</div>';
                });
                break;
            case 'scores':
                mui.each(item, function(index,scorer) {
                    str += '<div class="action-data-item">打分人:' + (scorer.scorerName?scorer.scorerName:'/') + ', 权重:' + scorer.weight + '</div>';
                });
                break;
            default:
            	    break;
          }
        });
        if(!hasNotifiers){
        		str +='<div class="action-data-item">移除所有知会人</div>';
        }
        break;
      default:
        break;
    }
    return str;
}